CVS commit: src/tools/llvm

2014-01-16 Thread Matt Thomas
Module Name:src
Committed By:   matt
Date:   Thu Jan 16 09:00:55 UTC 2014

Modified Files:
src/tools/llvm: Makefile

Log Message:
Pass HOST_CXX to llvm configure as CXX=${HOST_CXX:Q} since llvm wants c++
more than cc.


To generate a diff of this commit:
cvs rdiff -u -r1.17 -r1.18 src/tools/llvm/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/tools/llvm/Makefile
diff -u src/tools/llvm/Makefile:1.17 src/tools/llvm/Makefile:1.18
--- src/tools/llvm/Makefile:1.17	Mon Sep  2 14:34:57 2013
+++ src/tools/llvm/Makefile	Thu Jan 16 09:00:55 2014
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.17 2013/09/02 14:34:57 joerg Exp $
+#	$NetBSD: Makefile,v 1.18 2014/01/16 09:00:55 matt Exp $
 
 .include bsd.init.mk
 
@@ -16,7 +16,7 @@ config/config.status: ${LLVM_SRCDIR}/con
 	printf '#!/bin/sh\necho 2.7.3'  config/python
 	chmod 755 config/python
 	cd config  ${LLVM_SRCDIR}/configure ${LLVM_CONFIGURE_ARGS} \
-	--enable-optimized CC=${HOST_CC:Q} \
+	--enable-optimized CC=${HOST_CC:Q} CXX=${HOST_CXX:Q} \
 	--with-python=${.OBJDIR}/config/python
 # --disable-assertions
 



CVS commit: src/usr.bin/rump_wmd

2014-01-16 Thread Thomas Klausner
Module Name:src
Committed By:   wiz
Date:   Thu Jan 16 09:54:05 UTC 2014

Modified Files:
src/usr.bin/rump_wmd: rump_wmd.1 rump_wmd.sh

Log Message:
Sort options and option descriptions.
Document -h.


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/usr.bin/rump_wmd/rump_wmd.1 \
src/usr.bin/rump_wmd/rump_wmd.sh

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.bin/rump_wmd/rump_wmd.1
diff -u src/usr.bin/rump_wmd/rump_wmd.1:1.1 src/usr.bin/rump_wmd/rump_wmd.1:1.2
--- src/usr.bin/rump_wmd/rump_wmd.1:1.1	Thu Jan 16 01:54:47 2014
+++ src/usr.bin/rump_wmd/rump_wmd.1	Thu Jan 16 09:54:05 2014
@@ -1,4 +1,4 @@
-.\	$NetBSD: rump_wmd.1,v 1.1 2014/01/16 01:54:47 pooka Exp $
+.\	$NetBSD: rump_wmd.1,v 1.2 2014/01/16 09:54:05 wiz Exp $
 .\
 .\ Copyright (c) 2014 Antti Kantee.  All rights reserved.
 .\
@@ -31,8 +31,8 @@
 .Nd Resolve rump kernel component dependencies
 .Sh SYNOPSIS
 .Nm
+.Op Fl hv
 .Op Fl L Ar libdir
-.Op Fl v
 .Fl l Ar component
 .Sh DESCRIPTION
 The
@@ -49,6 +49,8 @@ is accepted as command line input by
 .Pp
 The command line options are:
 .Bl -tag -width indent
+.It Fl h
+Print the usage.
 .It Fl L Ar libdir
 By default, rump kernel components in
 .Pa /usr/lib
@@ -56,12 +58,12 @@ are examined.
 If this option is supplied, components in
 .Ar libdir
 are examined instead.
-.It Fl v
-Increase debug output from the utility.
-This option may be given multiple times.
 .It Fl l Ar component
 Resolve dependencies for the given component.
 This option may be given multiple time.
+.It Fl v
+Increase debug output from the utility.
+This option may be given multiple times.
 .El
 .Sh EXAMPLES
 Resolve dependencies for FFS:
@@ -80,6 +82,8 @@ DEBUG0: Searching component combinations
 DEBUG0: Found a set
 -lrumpnet -lrumpnet_net -lrumpvfs -lrumpfs_nfs -lrumpnet_netinet6 -lrumpnet_virtif
 .Ed
+.Sh SEE ALSO
+.Xr rump_server 1
 .Sh CAVEATS
 Since
 .Nm
@@ -87,8 +91,6 @@ uses trial-and-error brute force resolut
 If several seconds are spent for dependency resolution, the benefit of
 a rump kernel booting in 10ms is somewhat lost.
 Caching the output is highly recommended.
-.Sh FUNFACTS
+.Sh FUN FACTS
 .Nm
 is short for rump, where's my dependency.
-.Sh SEE ALSO
-.Xr rump_server 1
Index: src/usr.bin/rump_wmd/rump_wmd.sh
diff -u src/usr.bin/rump_wmd/rump_wmd.sh:1.1 src/usr.bin/rump_wmd/rump_wmd.sh:1.2
--- src/usr.bin/rump_wmd/rump_wmd.sh:1.1	Thu Jan 16 01:54:47 2014
+++ src/usr.bin/rump_wmd/rump_wmd.sh	Thu Jan 16 09:54:05 2014
@@ -38,7 +38,7 @@ die ()
 usage ()
 {
 
-	die Usage: $0 [-v] [-L libdir] -lrump_component [...]
+	die Usage: $0 [-hv] [-L libdir] -lrump_component [...]
 }
 
 unset FIRSTLIB



CVS commit: src/common/lib/libc

2014-01-16 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Thu Jan 16 11:43:49 UTC 2014

Modified Files:
src/common/lib/libc: Makefile.inc

Log Message:
Include bsd.own.mk in case it hasn't been yet.


To generate a diff of this commit:
cvs rdiff -u -r1.13 -r1.14 src/common/lib/libc/Makefile.inc

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/common/lib/libc/Makefile.inc
diff -u src/common/lib/libc/Makefile.inc:1.13 src/common/lib/libc/Makefile.inc:1.14
--- src/common/lib/libc/Makefile.inc:1.13	Wed Jan 15 20:58:09 2014
+++ src/common/lib/libc/Makefile.inc	Thu Jan 16 11:43:49 2014
@@ -1,4 +1,6 @@
-# $NetBSD: Makefile.inc,v 1.13 2014/01/15 20:58:09 joerg Exp $
+# $NetBSD: Makefile.inc,v 1.14 2014/01/16 11:43:49 joerg Exp $
+
+.include bsd.own.mk
 
 COMMON_DIR:=${.PARSEDIR}
 COMMON_CODEDIRS=atomic gen gmon inet md net stdlib string sys



CVS commit: src/sys/arch/hp700/hp700

2014-01-16 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Thu Jan 16 13:07:07 UTC 2014

Modified Files:
src/sys/arch/hp700/hp700: machdep.c

Log Message:
Drop CPU detection by features and panic if a CPU isn't detected via
PDC_MODEL_CPUID or cpu_model_cpuid.


To generate a diff of this commit:
cvs rdiff -u -r1.116 -r1.117 src/sys/arch/hp700/hp700/machdep.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/hp700/hp700/machdep.c
diff -u src/sys/arch/hp700/hp700/machdep.c:1.116 src/sys/arch/hp700/hp700/machdep.c:1.117
--- src/sys/arch/hp700/hp700/machdep.c:1.116	Sat Oct 19 13:16:30 2013
+++ src/sys/arch/hp700/hp700/machdep.c	Thu Jan 16 13:07:07 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: machdep.c,v 1.116 2013/10/19 13:16:30 skrll Exp $	*/
+/*	$NetBSD: machdep.c,v 1.117 2014/01/16 13:07:07 skrll Exp $	*/
 
 /*-
  * Copyright (c) 2001, 2002 The NetBSD Foundation, Inc.
@@ -58,7 +58,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: machdep.c,v 1.116 2013/10/19 13:16:30 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: machdep.c,v 1.117 2014/01/16 13:07:07 skrll Exp $);
 
 #include opt_cputype.h
 #include opt_ddb.h
@@ -685,9 +685,13 @@ cpuid(void)
 	error = pdcproc_model_cpuid(pdc_cpuid);
 	if (error  0) {
 		DPRINTF((WARNING: PDC_MODEL_CPUID error %d. 
-		Using cpu_modelno based cpu_type.\n, error));
+		Using cpu_modelno (%#x) based cpu_type.\n, error, cpu_modelno));
 
 		cpu_type = cpu_model_cpuid(cpu_modelno);
+		if (cpu_type == hpc_unknown) {
+			printf(WARNING: Unknown cpu_type for cpu_modelno %x\n,
+			   cpu_modelno);
+		}
 	} else {
 		DPRINTF((%s: cpuid.version  = %x\n, __func__,
 		pdc_cpuid.version));
@@ -774,26 +778,33 @@ cpuid(void)
 		pmap_hptsize = 0;
 	}
 
+	bool cpu_found = false;
 	if (cpu_version) {
+		DPRINTF((%s: looking for cpu_version %x\n, __func__,
+		cpu_version));
 		for (i = 0, p = cpu_types; i  __arraycount(cpu_types);
 		 i++, p++) {
-			if (p-hci_cpuversion == cpu_version)
+			if (p-hci_cpuversion == cpu_version) {
+cpu_found = true;
 break;
+			}
 		}
 	} else if (cpu_type != hpc_unknown) {
+		DPRINTF((%s: looking for cpu_type %d\n, __func__,
+		cpu_type));
 		for (i = 0, p = cpu_types; i  __arraycount(cpu_types);
 		 i++, p++) {
-			if (p-hci_cputype == cpu_type)
-break;
-		}
-	} else {
-		for (i = 0, p = cpu_types; i  __arraycount(cpu_types);
-		 i++, p++) {
-			if (p-hci_features == cpu_features)
+			if (p-hci_cputype == cpu_type) {
+cpu_found = true;
 break;
+			}
 		}
 	}
 
+	if (!cpu_found) {
+		panic(CPU detection failed. Please report the problem.);
+	}
+
 	hppa_cpu_info = p;
 
 	if (hppa_cpu_info-hci_chip_name == NULL)



CVS commit: src/sys/arch/hp700/hp700

2014-01-16 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Thu Jan 16 13:19:36 UTC 2014

Modified Files:
src/sys/arch/hp700/hp700: machdep.c

Log Message:
Add some 715 machines to cpu_model_cpuid including the 715/100 that
Ryo ONODERA has.


To generate a diff of this commit:
cvs rdiff -u -r1.117 -r1.118 src/sys/arch/hp700/hp700/machdep.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/hp700/hp700/machdep.c
diff -u src/sys/arch/hp700/hp700/machdep.c:1.117 src/sys/arch/hp700/hp700/machdep.c:1.118
--- src/sys/arch/hp700/hp700/machdep.c:1.117	Thu Jan 16 13:07:07 2014
+++ src/sys/arch/hp700/hp700/machdep.c	Thu Jan 16 13:19:36 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: machdep.c,v 1.117 2014/01/16 13:07:07 skrll Exp $	*/
+/*	$NetBSD: machdep.c,v 1.118 2014/01/16 13:19:36 skrll Exp $	*/
 
 /*-
  * Copyright (c) 2001, 2002 The NetBSD Foundation, Inc.
@@ -58,7 +58,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: machdep.c,v 1.117 2014/01/16 13:07:07 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: machdep.c,v 1.118 2014/01/16 13:19:36 skrll Exp $);
 
 #include opt_cputype.h
 #include opt_ddb.h
@@ -861,6 +861,13 @@ cpu_model_cpuid(int modelno)
 	case HPPA_BOARD_HPE25:
 	case HPPA_BOARD_HPE35:
 	case HPPA_BOARD_HPE45:
+	case HPPA_BOARD_HP715_80:
+	case HPPA_BOARD_HP715_64:
+	case HPPA_BOARD_HP715_100:
+	case HPPA_BOARD_HP715_100XC:
+	case HPPA_BOARD_HP715_100L:
+	case HPPA_BOARD_HP715_120L:
+	case HPPA_BOARD_HP715_80M:
 		return hpcxl;
 
 	case HPPA_BOARD_HP735_99:



CVS commit: src/external/bsd/dhcp

2014-01-16 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Jan 16 13:55:46 UTC 2014

Modified Files:
src/external/bsd/dhcp: Makefile.inc

Log Message:
kill debug


To generate a diff of this commit:
cvs rdiff -u -r1.9 -r1.10 src/external/bsd/dhcp/Makefile.inc

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/dhcp/Makefile.inc
diff -u src/external/bsd/dhcp/Makefile.inc:1.9 src/external/bsd/dhcp/Makefile.inc:1.10
--- src/external/bsd/dhcp/Makefile.inc:1.9	Wed Jan 15 20:15:33 2014
+++ src/external/bsd/dhcp/Makefile.inc	Thu Jan 16 08:55:46 2014
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile.inc,v 1.9 2014/01/16 01:15:33 christos Exp $
+# $NetBSD: Makefile.inc,v 1.10 2014/01/16 13:55:46 christos Exp $
 
 WARNS?=	1	# XXX -Wshadow -Wcast-qual -Wsign-compare
 
@@ -20,7 +20,7 @@ DSTOBJDIR!=cd ${.PARSEDIR}/lib/dst  ${
 .if (${USE_INET6} != no)
 CPPFLAGS+=	-DDHCPv6
 .endif
-CPPFLAGS+= -DISC_PLATFORM_USETHREADS -DHAVE_CONFIG_H -DDEBUG
+CPPFLAGS+= -DISC_PLATFORM_USETHREADS -DHAVE_CONFIG_H
 CPPFLAGS+= -I${DIST} -I${DIST}/includes -I${DIST}/../include
 CPPFLAGS+= -I${BIND} -I${BIND}/includes -I${BIND}/../include
 .for dir in isc dns



CVS commit: src/sys/rump/dev/lib/libopencrypto

2014-01-16 Thread Paul Goyette
Module Name:src
Committed By:   pgoyette
Date:   Thu Jan 16 14:12:09 UTC 2014

Modified Files:
src/sys/rump/dev/lib/libopencrypto: Makefile

Log Message:
Don't bring in the zlib stuff at build time.  This will get resolved
when the user starts the rump_server process.

OK pooka@


To generate a diff of this commit:
cvs rdiff -u -r1.3 -r1.4 src/sys/rump/dev/lib/libopencrypto/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/rump/dev/lib/libopencrypto/Makefile
diff -u src/sys/rump/dev/lib/libopencrypto/Makefile:1.3 src/sys/rump/dev/lib/libopencrypto/Makefile:1.4
--- src/sys/rump/dev/lib/libopencrypto/Makefile:1.3	Thu Jan 16 02:38:20 2014
+++ src/sys/rump/dev/lib/libopencrypto/Makefile	Thu Jan 16 14:12:09 2014
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.3 2014/01/16 02:38:20 pgoyette Exp $
+#	$NetBSD: Makefile,v 1.4 2014/01/16 14:12:09 pgoyette Exp $
 #
 
 .PATH:	${.CURDIR}/../../../../opencrypto
@@ -26,10 +26,6 @@ SRCS+=	cryptosoft.c
 SRCS+=	deflate.c
 SRCS+=	gmac.c
 
-# deflate.c also requires zlib, so include the appropriate library
-
-LDADD+=	-lrumpkern_z
-
 CPPFLAGS+=	-I${RUMPTOP}/librump/rumpvfs
 
 .include bsd.lib.mk



CVS commit: src/distrib/sets/lists/base

2014-01-16 Thread Paul Goyette
Module Name:src
Committed By:   pgoyette
Date:   Thu Jan 16 14:46:36 UTC 2014

Modified Files:
src/distrib/sets/lists/base: mi

Log Message:
Add new file bsd.host.mk to sets list to unbreak the build.

(hello, christos!)


To generate a diff of this commit:
cvs rdiff -u -r1.1059 -r1.1060 src/distrib/sets/lists/base/mi

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/base/mi
diff -u src/distrib/sets/lists/base/mi:1.1059 src/distrib/sets/lists/base/mi:1.1060
--- src/distrib/sets/lists/base/mi:1.1059	Thu Jan 16 01:54:47 2014
+++ src/distrib/sets/lists/base/mi	Thu Jan 16 14:46:36 2014
@@ -1,4 +1,4 @@
-# $NetBSD: mi,v 1.1059 2014/01/16 01:54:47 pooka Exp $
+# $NetBSD: mi,v 1.1060 2014/01/16 14:46:36 pgoyette Exp $
 #
 # Note:	Don't delete entries from here - mark them as obsolete instead,
 #	unless otherwise stated below.
@@ -4313,6 +4313,7 @@
 ./usr/share/mk/bsd.endian.mk			base-mk-share		share
 ./usr/share/mk/bsd.files.mk			base-mk-share		share
 ./usr/share/mk/bsd.gcc.mk			base-mk-share		share
+./usr/share/mk/bsd.host.mk			base-mk-share		share
 ./usr/share/mk/bsd.hostlib.mk			base-mk-share		share
 ./usr/share/mk/bsd.hostprog.mk			base-mk-share		share
 ./usr/share/mk/bsd.inc.mk			base-mk-share		share



CVS commit: src/lib/librumpuser

2014-01-16 Thread Antti Kantee
Module Name:src
Committed By:   pooka
Date:   Thu Jan 16 16:03:33 UTC 2014

Modified Files:
src/lib/librumpuser: rumpuser_port.h

Log Message:
Do not force _FILE_OFFSET_BITS=64 here.  It's no longer strictly speaking
required (rumpuser interface no longer uses off_t) and force-defining
it causes foo() to magically become foo64() on glibc (even on 64bit
platforms).


To generate a diff of this commit:
cvs rdiff -u -r1.27 -r1.28 src/lib/librumpuser/rumpuser_port.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/librumpuser/rumpuser_port.h
diff -u src/lib/librumpuser/rumpuser_port.h:1.27 src/lib/librumpuser/rumpuser_port.h:1.28
--- src/lib/librumpuser/rumpuser_port.h:1.27	Wed Jan 15 16:53:15 2014
+++ src/lib/librumpuser/rumpuser_port.h	Thu Jan 16 16:03:33 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: rumpuser_port.h,v 1.27 2014/01/15 16:53:15 pooka Exp $	*/
+/*	$NetBSD: rumpuser_port.h,v 1.28 2014/01/16 16:03:33 pooka Exp $	*/
 
 /*
  * Portability header for non-NetBSD platforms.
@@ -47,7 +47,6 @@
 #ifdef __linux__
 #define _XOPEN_SOURCE 600
 #define _BSD_SOURCE
-#define _FILE_OFFSET_BITS 64
 #define _GNU_SOURCE
 #include features.h
 #endif
@@ -55,8 +54,6 @@
 #if defined(__sun__)
 #  if defined(RUMPUSER_NO_FILE_OFFSET_BITS)
 #undef _FILE_OFFSET_BITS
-#  else
-#define _FILE_OFFSET_BITS 64
 #  endif
 #endif
 



CVS commit: src/include

2014-01-16 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Jan 16 17:22:06 UTC 2014

Modified Files:
src/include: err.h

Log Message:
Add the {v,}{warn,err}c function flavors from FreeBSD


To generate a diff of this commit:
cvs rdiff -u -r1.16 -r1.17 src/include/err.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/include/err.h
diff -u src/include/err.h:1.16 src/include/err.h:1.17
--- src/include/err.h:1.16	Sun Jul 17 16:54:34 2011
+++ src/include/err.h	Thu Jan 16 12:22:06 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: err.h,v 1.16 2011/07/17 20:54:34 joerg Exp $	*/
+/*	$NetBSD: err.h,v 1.17 2014/01/16 17:22:06 christos Exp $	*/
 
 /*-
  * Copyright (c) 1993
@@ -46,6 +46,10 @@ __dead void	errx(int, const char *, ...)
 		 __printflike(2, 3) __dead;
 __dead void	verrx(int, const char *, va_list)
 		__printflike(2, 0) __dead;
+__dead void	errc(int, int, const char *, ...)
+		 __printflike(3, 4) __dead;
+__dead void	verrc(int, int, const char *, va_list)
+		__printflike(3, 0) __dead;
 void		warn(const char *, ...)
 		__printflike(1, 2);
 void		vwarn(const char *, va_list)
@@ -54,6 +58,10 @@ void		warnx(const char *, ...)
 		__printflike(1, 2);
 void		vwarnx(const char *, va_list)
 		__printflike(1, 0);
+void		warnc(int, const char *, ...)
+		__printflike(2, 3);
+void		vwarnc(int, const char *, va_list)
+		__printflike(2, 0);
 __END_DECLS
 
 #endif /* !_ERR_H_ */



CVS commit: src/lib/libc

2014-01-16 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Jan 16 17:21:38 UTC 2014

Modified Files:
src/lib/libc: shlib_version
src/lib/libc/gen: Makefile.inc err.3 verr.c vwarn.c
Added Files:
src/lib/libc/gen: _errc.c _verrc.c _vwarnc.c _warnc.c errc.c verrc.c
vwarnc.c warnc.c

Log Message:
Add the {v,}{err,warn}c flavors, from FreeBSD.


To generate a diff of this commit:
cvs rdiff -u -r1.247 -r1.248 src/lib/libc/shlib_version
cvs rdiff -u -r1.185 -r1.186 src/lib/libc/gen/Makefile.inc
cvs rdiff -u -r0 -r1.1 src/lib/libc/gen/_errc.c src/lib/libc/gen/_verrc.c \
src/lib/libc/gen/_vwarnc.c src/lib/libc/gen/_warnc.c \
src/lib/libc/gen/errc.c src/lib/libc/gen/verrc.c \
src/lib/libc/gen/vwarnc.c src/lib/libc/gen/warnc.c
cvs rdiff -u -r1.20 -r1.21 src/lib/libc/gen/err.3
cvs rdiff -u -r1.15 -r1.16 src/lib/libc/gen/verr.c src/lib/libc/gen/vwarn.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/shlib_version
diff -u src/lib/libc/shlib_version:1.247 src/lib/libc/shlib_version:1.248
--- src/lib/libc/shlib_version:1.247	Tue Jan 14 12:20:57 2014
+++ src/lib/libc/shlib_version	Thu Jan 16 12:21:38 2014
@@ -1,4 +1,4 @@
-#	$NetBSD: shlib_version,v 1.247 2014/01/14 17:20:57 joerg Exp $
+#	$NetBSD: shlib_version,v 1.248 2014/01/16 17:21:38 christos Exp $
 #	Remember to update distrib/sets/lists/base/shl.* when changing
 #
 # things we wish to do on next major version bump:
@@ -40,4 +40,4 @@
 # - consolidate ownership with crt0.o and avoid common symbols
 # - redo stdin/stdout/stderr to not require copy relocations
 major=12
-minor=188
+minor=189

Index: src/lib/libc/gen/Makefile.inc
diff -u src/lib/libc/gen/Makefile.inc:1.185 src/lib/libc/gen/Makefile.inc:1.186
--- src/lib/libc/gen/Makefile.inc:1.185	Sat Nov  3 15:39:21 2012
+++ src/lib/libc/gen/Makefile.inc	Thu Jan 16 12:21:38 2014
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile.inc,v 1.185 2012/11/03 19:39:21 christos Exp $
+#	$NetBSD: Makefile.inc,v 1.186 2014/01/16 17:21:38 christos Exp $
 #	from: @(#)Makefile.inc	8.6 (Berkeley) 5/4/95
 
 # gen sources
@@ -8,7 +8,7 @@ SRCS+= 	_errno.c alarm.c alphasort.c arc
 	closedir.c closefrom.c \
 	confstr.c ctermid.c ctype_.c daemon.c \
 	dehumanize_number.c devname.c dirname.c disklabel.c err.c errx.c \
-	errlist.c errno.c execl.c execle.c execlp.c execv.c execvp.c \
+	errc.c errlist.c errno.c execl.c execle.c execlp.c execv.c execvp.c \
 	extattr.c fmtcheck.c fmtmsg.c fnmatch.c fstab.c ftok.c \
 	fts.c ftw.c getbsize.c getcap.c getcwd.c \
 	getdevmajor.c getdomainname.c getgrent.c \
@@ -32,11 +32,12 @@ SRCS+= 	_errno.c alarm.c alphasort.c arc
 	times.c toascii.c tolower_.c ttyname.c ttyslot.c toupper_.c ualarm.c \
 	ulimit.c uname.c unvis.c usleep.c utime.c utimens.c utmp.c \
 	utmpx.c valloc.c vis.c wait.c wait3.c waitpid.c warn.c warnx.c \
-	vwarn.c vwarnx.c verr.c verrx.c wordexp.c
+	warnc.c vwarn.c vwarnx.c vwarnc.c verr.c verrx.c verrc.c wordexp.c
 
 # indirect reference stubs, to be removed soon.
-SRCS+=	_err.c _errx.c \
-	_sysconf.c _verr.c _verrx.c _vwarn.c _vwarnx.c _warn.c _warnx.c
+SRCS+=	_err.c _errx.c _errc.c \
+	_sysconf.c _verr.c _verrx.c _verrc.c _vwarn.c _vwarnx.c _vwarnc.c \
+	_warn.c _warnx.c _warnc.c
 
 # uses alloca
 COPTS.execvp.c = -Wno-stack-protector
@@ -96,7 +97,8 @@ MLINKS+=endutxent.3 getutxent.3 endutxen
 	endutxent.3 getutxline.3 endutxent.3 pututxline.3 \
 	endutxent.3 setutxent.3
 MLINKS+=err.3 verr.3 err.3 errx.3 err.3 verrx.3 err.3 warn.3 err.3 vwarn.3 \
-err.3 warnx.3 err.3 vwarnx.3
+err.3 warnx.3 err.3 vwarnx.3 err.3 errc.3 err.3 verrc.3 err.3 warnc.3 \
+	err.3 vwarnc.3
 MLINKS+=exec.3 execl.3 exec.3 execle.3 exec.3 execlp.3 exec.3 execv.3 \
 	exec.3 execvp.3 exec.3 exect.3
 MLINKS+=extattr_namespace_to_string.3 extattr_string_to_namespace.3 \

Index: src/lib/libc/gen/err.3
diff -u src/lib/libc/gen/err.3:1.20 src/lib/libc/gen/err.3:1.21
--- src/lib/libc/gen/err.3:1.20	Mon Mar 22 15:30:53 2010
+++ src/lib/libc/gen/err.3	Thu Jan 16 12:21:38 2014
@@ -1,4 +1,4 @@
-.\ $NetBSD: err.3,v 1.20 2010/03/22 19:30:53 joerg Exp $
+.\ $NetBSD: err.3,v 1.21 2014/01/16 17:21:38 christos Exp $
 .\
 .\ Copyright (c) 1993
 .\	The Regents of the University of California.  All rights reserved.
@@ -29,7 +29,7 @@
 .\
 .\	@(#)err.3	8.1 (Berkeley) 6/9/93
 .\
-.Dd March 21, 2001
+.Dd January 16, 2014
 .Dt ERR 3
 .Os
 .Sh NAME
@@ -37,10 +37,14 @@
 .Nm verr ,
 .Nm errx ,
 .Nm verrx ,
+.Nm errc ,
+.Nm verrc ,
 .Nm warn ,
 .Nm vwarn ,
 .Nm warnx ,
-.Nm vwarnx
+.Nm vwarnx ,
+.Nm warnc ,
+.Nm vwarnc
 .Nd formatted error messages
 .Sh LIBRARY
 .Lb libc
@@ -55,6 +59,10 @@
 .Ft void
 .Fn verrx int status const char *fmt va_list args
 .Ft void
+.Fn errc int status int code const char *fmt ...
+.Ft void
+.Fn verrc int status int code const char *fmt va_list args
+.Ft void
 .Fn warn const char *fmt ...
 .Ft void
 .Fn vwarn const char *fmt va_list args
@@ -62,6 +70,10 @@
 

CVS commit: src/distrib/sets/lists/comp

2014-01-16 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Jan 16 17:30:33 UTC 2014

Modified Files:
src/distrib/sets/lists/comp: mi

Log Message:
Add man pages for {v,}{err,warn}c


To generate a diff of this commit:
cvs rdiff -u -r1.1874 -r1.1875 src/distrib/sets/lists/comp/mi

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/comp/mi
diff -u src/distrib/sets/lists/comp/mi:1.1874 src/distrib/sets/lists/comp/mi:1.1875
--- src/distrib/sets/lists/comp/mi:1.1874	Tue Jan 14 12:18:43 2014
+++ src/distrib/sets/lists/comp/mi	Thu Jan 16 12:30:33 2014
@@ -1,4 +1,4 @@
-#	$NetBSD: mi,v 1.1874 2014/01/14 17:18:43 pgoyette Exp $
+#	$NetBSD: mi,v 1.1875 2014/01/16 17:30:33 christos Exp $
 #
 # Note: don't delete entries from here - mark them as obsolete instead.
 #
@@ -6120,6 +6120,7 @@
 ./usr/share/man/cat3/erfcf.0			comp-c-catman		.cat
 ./usr/share/man/cat3/erff.0			comp-c-catman		.cat
 ./usr/share/man/cat3/err.0			comp-c-catman		.cat
+./usr/share/man/cat3/errc.0			comp-c-catman		.cat
 ./usr/share/man/cat3/error_message.0		comp-krb5-catman	kerberos,.cat
 ./usr/share/man/cat3/error_table_name.0		comp-krb5-catman	kerberos,.cat
 ./usr/share/man/cat3/errx.0			comp-c-catman		.cat
@@ -9162,6 +9163,7 @@
 ./usr/share/man/cat3/vasprintf.0		comp-c-catman		.cat
 ./usr/share/man/cat3/vdprintf.0			comp-c-catman		.cat
 ./usr/share/man/cat3/verr.0			comp-c-catman		.cat
+./usr/share/man/cat3/verrc.0			comp-c-catman		.cat
 ./usr/share/man/cat3/verrx.0			comp-c-catman		.cat
 ./usr/share/man/cat3/vfprintf.0			comp-c-catman		.cat
 ./usr/share/man/cat3/vfscanf.0			comp-c-catman		.cat
@@ -9185,6 +9187,7 @@
 ./usr/share/man/cat3/vsyslogp_r.0		comp-c-catman		.cat
 ./usr/share/man/cat3/vtimes.0			comp-obsolete		obsolete
 ./usr/share/man/cat3/vwarn.0			comp-c-catman		.cat
+./usr/share/man/cat3/vwarnc.0			comp-c-catman		.cat
 ./usr/share/man/cat3/vwarnx.0			comp-c-catman		.cat
 ./usr/share/man/cat3/vwprintf.0			comp-c-catman		.cat
 ./usr/share/man/cat3/vwscanf.0			comp-c-catman		.cat
@@ -9194,6 +9197,7 @@
 ./usr/share/man/cat3/waddnstr.0			comp-c-catman		.cat
 ./usr/share/man/cat3/waddstr.0			comp-c-catman		.cat
 ./usr/share/man/cat3/warn.0			comp-c-catman		.cat
+./usr/share/man/cat3/warnc.0			comp-c-catman		.cat
 ./usr/share/man/cat3/warnx.0			comp-c-catman		.cat
 ./usr/share/man/cat3/wattr_get.0		comp-c-catman		.cat
 ./usr/share/man/cat3/wattr_off.0		comp-c-catman		.cat
@@ -12704,6 +12708,7 @@
 ./usr/share/man/html3/erfcf.html		comp-c-htmlman		html
 ./usr/share/man/html3/erff.html			comp-c-htmlman		html
 ./usr/share/man/html3/err.html			comp-c-htmlman		html
+./usr/share/man/html3/errc.html			comp-c-htmlman		html
 ./usr/share/man/html3/error_message.html	comp-krb5-htmlman	kerberos,html
 ./usr/share/man/html3/error_table_name.html	comp-krb5-htmlman	kerberos,html
 ./usr/share/man/html3/errx.html			comp-c-htmlman		html
@@ -15665,6 +15670,7 @@
 ./usr/share/man/html3/vasprintf.html		comp-c-htmlman		html
 ./usr/share/man/html3/vdprintf.html		comp-c-htmlman		html
 ./usr/share/man/html3/verr.html			comp-c-htmlman		html
+./usr/share/man/html3/verrc.html		comp-c-htmlman		html
 ./usr/share/man/html3/verrx.html		comp-c-htmlman		html
 ./usr/share/man/html3/vfprintf.html		comp-c-htmlman		html
 ./usr/share/man/html3/vfscanf.html		comp-c-htmlman		html
@@ -15685,6 +15691,7 @@
 ./usr/share/man/html3/vsyslogp.html		comp-c-htmlman		html
 ./usr/share/man/html3/vsyslogp_r.html		comp-c-htmlman		html
 ./usr/share/man/html3/vwarn.html		comp-c-htmlman		html
+./usr/share/man/html3/vwarnc.html		comp-c-htmlman		html
 ./usr/share/man/html3/vwarnx.html		comp-c-htmlman		html
 ./usr/share/man/html3/vwprintf.html		comp-c-htmlman		html
 ./usr/share/man/html3/vwscanf.html		comp-c-htmlman		html
@@ -15694,6 +15701,7 @@
 ./usr/share/man/html3/waddnstr.html		comp-c-htmlman		html
 ./usr/share/man/html3/waddstr.html		comp-c-htmlman		html
 ./usr/share/man/html3/warn.html			comp-c-htmlman		html
+./usr/share/man/html3/warnc.html		comp-c-htmlman		html
 ./usr/share/man/html3/warnx.html		comp-c-htmlman		html
 ./usr/share/man/html3/wattr_get.html		comp-c-htmlman		html
 ./usr/share/man/html3/wattr_off.html		comp-c-htmlman		html
@@ -19200,6 +19208,7 @@
 ./usr/share/man/man3/erfcf.3			comp-c-man		.man
 ./usr/share/man/man3/erff.3			comp-c-man		.man
 ./usr/share/man/man3/err.3			comp-c-man		.man
+./usr/share/man/man3/errc.3			comp-c-man		.man
 ./usr/share/man/man3/error_message.3		comp-krb5-man		kerberos,.man
 ./usr/share/man/man3/error_table_name.3		comp-krb5-man		kerberos,.man
 ./usr/share/man/man3/errx.3			comp-c-man		.man
@@ -22238,6 +22247,7 @@
 ./usr/share/man/man3/vasprintf.3		comp-c-man		.man
 ./usr/share/man/man3/vdprintf.3			comp-c-man		.man
 ./usr/share/man/man3/verr.3			comp-c-man		.man
+./usr/share/man/man3/verrc.3			comp-c-man		.man
 ./usr/share/man/man3/verrx.3			comp-c-man		.man
 ./usr/share/man/man3/vfprintf.3			comp-c-man		.man
 

CVS commit: src/tools/compat

2014-01-16 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Jan 16 17:24:56 UTC 2014

Modified Files:
src/tools/compat: Makefile

Log Message:
Add the {v,}{err,warn}c functions


To generate a diff of this commit:
cvs rdiff -u -r1.71 -r1.72 src/tools/compat/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/tools/compat/Makefile
diff -u src/tools/compat/Makefile:1.71 src/tools/compat/Makefile:1.72
--- src/tools/compat/Makefile:1.71	Thu Jan  9 06:31:12 2014
+++ src/tools/compat/Makefile	Thu Jan 16 12:24:56 2014
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.71 2014/01/09 11:31:12 apb Exp $
+#	$NetBSD: Makefile,v 1.72 2014/01/16 17:24:56 christos Exp $
 
 HOSTLIB=	nbcompat
 
@@ -20,8 +20,9 @@ SRCS=		atoll.c basename.c cdbr.c cdbw.c 
 		stat_flags.c strlcat.c strlcpy.c strmode.c \
 		strndup.c strnlen.c \
 		strsep.c strsuftoll.c strtoll.c \
-		unvis.c vis.c err.c errx.c verr.c verrx.c \
-		vwarn.c vwarnx.c warn.c warnx.c fts.c glob.c efun.c
+		unvis.c vis.c err.c errx.c errc.c verr.c verrx.c verrc.c \
+		vwarn.c vwarnx.c vwarnc.c warn.c warnx.c warnc.c \
+		fts.c glob.c efun.c
 
 BUILD_OSTYPE!=  uname -s
 



CVS commit: src/tests/crypto/opencrypto

2014-01-16 Thread Paul Goyette
Module Name:src
Committed By:   pgoyette
Date:   Thu Jan 16 18:09:55 UTC 2014

Modified Files:
src/tests/crypto/opencrypto: h_xcbcmac.c

Log Message:
Include all of the examples from RFC3566


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/tests/crypto/opencrypto/h_xcbcmac.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/tests/crypto/opencrypto/h_xcbcmac.c
diff -u src/tests/crypto/opencrypto/h_xcbcmac.c:1.1 src/tests/crypto/opencrypto/h_xcbcmac.c:1.2
--- src/tests/crypto/opencrypto/h_xcbcmac.c:1.1	Tue Jan 14 17:51:39 2014
+++ src/tests/crypto/opencrypto/h_xcbcmac.c	Thu Jan 16 18:09:55 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: h_xcbcmac.c,v 1.1 2014/01/14 17:51:39 pgoyette Exp $ */
+/* $NetBSD: h_xcbcmac.c,v 1.2 2014/01/16 18:09:55 pgoyette Exp $ */
 
 /*-
  * Copyright (c) 2014 The NetBSD Foundation, Inc.
@@ -36,20 +36,43 @@
 
 #include crypto/cryptodev.h
 
+
+/* test vectors from RFC3566 */
 unsigned char key[16] = {
 	0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07,
 	0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f
 };
-char plaintx[] = {0x00, 0x01, 0x02};
-const unsigned char ciphertx[16] = {
-	0x21, 0xc6, 0x0d, 0xa5, 0x34, 0x24, 0x8b, 0xce,
-	0x95, 0x86, 0x64, 0xb3, 0x66, 0x77, 0x9b, 0x4c
+char plaintx[1000] = {
+	0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07,
+	0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f,
+	0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17,
+	0x18, 0x19, 0x1a, 0x1b, 0x1c, 0x1d, 0x1e, 0x1f,
+	0x20, 0x21
+};
+const struct {
+	size_t len;
+	unsigned char mac[12];
+} tests[] = {
+	{0, { 0x75, 0xf0, 0x25, 0x1d, 0x52, 0x8a,
+		  0xc0, 0x1c, 0x45, 0x73, 0xdf, 0xd5 } },
+	{3, { 0x5b, 0x37, 0x65, 0x80, 0xae, 0x2f,
+		  0x19, 0xaf, 0xe7, 0x21, 0x9c, 0xee } },
+	{   16, { 0xd2, 0xa2, 0x46, 0xfa, 0x34, 0x9b,
+		  0x68, 0xa7, 0x99, 0x98, 0xa4, 0x39 } },
+	{   20, { 0x47, 0xf5, 0x1b, 0x45, 0x64, 0x96,
+		  0x62, 0x15, 0xb8, 0x98, 0x5c, 0x63 } },
+	{   32, { 0xf5, 0x4f, 0x0e, 0xc8, 0xd2, 0xb9,
+		  0xf3, 0xd3, 0x68, 0x07, 0x73, 0x4b } },
+	{   34,	{ 0xbe, 0xcb, 0xb3, 0xbc, 0xcd, 0xb5,
+		  0x18, 0xa3, 0x06, 0x77, 0xd5, 0x48 } },
+	{ 1000,	{ 0xf0, 0xda, 0xfe, 0xe8, 0x95, 0xdb,
+		  0x30, 0x25, 0x37, 0x61, 0x10, 0x3b } },
 };
 
 int
 main(void)
 {
-	int fd, res;
+	int fd, res, i;
 	struct session_op cs;
 	struct crypt_op co;
 	unsigned char buf[16];
@@ -65,26 +88,21 @@ main(void)
 	if (res  0)
 		err(1, CIOCGSESSION);
 
-	memset(co, 0, sizeof(co));
-	memset(buf, 0, sizeof(buf));
-	co.ses = cs.ses;
-	co.op = COP_ENCRYPT;
-	co.len = 0 /*sizeof(plaintx)*/;
-	co.src = plaintx;
-	co.mac = buf;
-	res = ioctl(fd, CIOCCRYPT, co);
-	if (res  0)
-		err(1, CIOCCRYPT);
-#if 0
-	if (memcmp(co.dst, ciphertx, sizeof(ciphertx)))
-		errx(1, verification failed);
-#else
-	{
-		unsigned int i;
-		for (i = 0; i  sizeof(buf); i++)
-			printf(%02x , buf[i]);
-		printf(\n);
+	for (i = 0; i  sizeof(tests)/sizeof(tests[0]); i++) {
+		memset(co, 0, sizeof(co));
+		memset(buf, 0, sizeof(buf));
+		if (tests[i].len == sizeof(plaintx))
+			memset(plaintx, 0, sizeof(plaintx));
+		co.ses = cs.ses;
+		co.op = COP_ENCRYPT;
+		co.len = tests[i].len;
+		co.src = plaintx;
+		co.mac = buf;
+		res = ioctl(fd, CIOCCRYPT, co);
+		if (res  0)
+			err(1, CIOCCRYPT test %d, i);
+		if (memcmp(buf, tests[i].mac, sizeof(tests[i].mac)))
+			errx(1, verification failed test %d, i);
 	}
-#endif
 	return 0;
 }



CVS commit: src/sys/dev/pci

2014-01-16 Thread Jonathan A. Kollasch
Module Name:src
Committed By:   jakllsch
Date:   Thu Jan 16 18:41:10 UTC 2014

Modified Files:
src/sys/dev/pci: genfb_pci.c

Log Message:
Fix PR kern/46376 with Nat Sloss's patch (with slight modification).
Serial console now works on x86 with genfb enabled.


To generate a diff of this commit:
cvs rdiff -u -r1.34 -r1.35 src/sys/dev/pci/genfb_pci.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/pci/genfb_pci.c
diff -u src/sys/dev/pci/genfb_pci.c:1.34 src/sys/dev/pci/genfb_pci.c:1.35
--- src/sys/dev/pci/genfb_pci.c:1.34	Tue Mar 13 18:40:31 2012
+++ src/sys/dev/pci/genfb_pci.c	Thu Jan 16 18:41:10 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: genfb_pci.c,v 1.34 2012/03/13 18:40:31 elad Exp $ */
+/*	$NetBSD: genfb_pci.c,v 1.35 2014/01/16 18:41:10 jakllsch Exp $ */
 
 /*-
  * Copyright (c) 2007 Michael Lorenz
@@ -27,7 +27,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: genfb_pci.c,v 1.34 2012/03/13 18:40:31 elad Exp $);
+__KERNEL_RCSID(0, $NetBSD: genfb_pci.c,v 1.35 2014/01/16 18:41:10 jakllsch Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -99,8 +99,10 @@ pci_genfb_attach(device_t parent, device
 	struct pci_genfb_softc *sc = device_private(self);
 	struct pci_attach_args *pa = aux;
 	struct genfb_ops ops;
+	prop_dictionary_t dict;
 	pcireg_t rom;
 	int idx, bar, type;
+	bool isconsole;
 
 	pci_aprint_devinfo(pa, NULL);
 
@@ -185,6 +187,10 @@ pci_genfb_attach(device_t parent, device
 	ops.genfb_mmap = pci_genfb_mmap;
 	ops.genfb_borrow = pci_genfb_borrow;
 
+	isconsole = genfb_is_console() != 0;
+	dict = device_properties(self);
+	prop_dictionary_set_bool(dict, is_console, isconsole);
+
 	if (genfb_attach(sc-sc_gen, ops) == 0) {
 
 		/* now try to attach a DRM */



CVS commit: src/external/bsd/llvm

2014-01-16 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Thu Jan 16 19:08:11 UTC 2014

Modified Files:
src/external/bsd/llvm: Makefile.inc

Log Message:
Disable compiler version check for now.


To generate a diff of this commit:
cvs rdiff -u -r1.69 -r1.70 src/external/bsd/llvm/Makefile.inc

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/llvm/Makefile.inc
diff -u src/external/bsd/llvm/Makefile.inc:1.69 src/external/bsd/llvm/Makefile.inc:1.70
--- src/external/bsd/llvm/Makefile.inc:1.69	Wed Jan 15 22:21:34 2014
+++ src/external/bsd/llvm/Makefile.inc	Thu Jan 16 19:08:11 2014
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile.inc,v 1.69 2014/01/15 22:21:34 joerg Exp $
+#	$NetBSD: Makefile.inc,v 1.70 2014/01/16 19:08:11 joerg Exp $
 
 .if !defined(LLVM_TOPLEVEL_MK)
 LLVM_TOPLEVEL_MK=
@@ -70,7 +70,7 @@ LLVM_CONFIGURE_ARGS=	\
 	--with-c-include-dirs=/usr/include/clang-${CLANG_VERSION}:/usr/include \
 	--disable-timestamps --prefix=/usr --sysconfdir=/etc/llvm \
 	--with-clang-srcdir=${CLANG_SRCDIR} \
-	--host=${LLVM_PLATFORM} \
+	--host=${LLVM_PLATFORM} --disable-compiler-version-checks \
 	llvm_cv_gnu_make_command=${MAKE}
 
 .for tool in circo dot dotty fdp neato twopi xdot



CVS commit: src/lib/libc/include

2014-01-16 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Thu Jan 16 19:16:42 UTC 2014

Modified Files:
src/lib/libc/include: namespace.h

Log Message:
Fix (v)errc/(v)warnc.


To generate a diff of this commit:
cvs rdiff -u -r1.170 -r1.171 src/lib/libc/include/namespace.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/include/namespace.h
diff -u src/lib/libc/include/namespace.h:1.170 src/lib/libc/include/namespace.h:1.171
--- src/lib/libc/include/namespace.h:1.170	Thu Dec  5 21:17:23 2013
+++ src/lib/libc/include/namespace.h	Thu Jan 16 19:16:42 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: namespace.h,v 1.170 2013/12/05 21:17:23 joerg Exp $	*/
+/*	$NetBSD: namespace.h,v 1.171 2014/01/16 19:16:42 joerg Exp $	*/
 
 /*-
  * Copyright (c) 1997-2004 The NetBSD Foundation, Inc.
@@ -42,6 +42,7 @@
 #define difftime	_difftime
 #define devname_r	_devname_r
 #define err		_err
+#define errc		_errc
 #define errx		_errx
 #ifdef _REENTRANT
 #define fileno		_fileno
@@ -80,10 +81,13 @@
 #define	sys_nsig	_sys_nsig
 #define sysconf		__sysconf
 #define verr		_verr
+#define verrc		_verrc
 #define verrx		_verrx
 #define vwarn		_vwarn
+#define vwarnc		_vwarnc
 #define vwarnx		_vwarnx
 #define warn		_warn
+#define warnc		_warnc
 #define warnx		_warnx
 
 #ifdef __weak_alias



CVS commit: src/lib/libc/citrus/modules

2014-01-16 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Jan 16 20:28:51 UTC 2014

Modified Files:
src/lib/libc/citrus/modules: citrus_euc.c

Log Message:
PR/47602: Christos Zoulas: getwc() modifies input instead of returning EILSEQ.
Waited for almost a year for feedback and there was none.


To generate a diff of this commit:
cvs rdiff -u -r1.15 -r1.16 src/lib/libc/citrus/modules/citrus_euc.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/citrus/modules/citrus_euc.c
diff -u src/lib/libc/citrus/modules/citrus_euc.c:1.15 src/lib/libc/citrus/modules/citrus_euc.c:1.16
--- src/lib/libc/citrus/modules/citrus_euc.c:1.15	Tue May 28 12:57:56 2013
+++ src/lib/libc/citrus/modules/citrus_euc.c	Thu Jan 16 15:28:51 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: citrus_euc.c,v 1.15 2013/05/28 16:57:56 joerg Exp $	*/
+/*	$NetBSD: citrus_euc.c,v 1.16 2014/01/16 20:28:51 christos Exp $	*/
 
 /*-
  * Copyright (c)2002 Citrus Project,
@@ -60,7 +60,7 @@
 
 #include sys/cdefs.h
 #if defined(LIBC_SCCS)  !defined(lint)
-__RCSID($NetBSD: citrus_euc.c,v 1.15 2013/05/28 16:57:56 joerg Exp $);
+__RCSID($NetBSD: citrus_euc.c,v 1.16 2014/01/16 20:28:51 christos Exp $);
 #endif /* LIBC_SCCS and not lint */
 
 #include assert.h
@@ -273,7 +273,8 @@ _citrus_EUC_mbrtowc_priv(_EUCEncodingInf
 	wchar = 0;
 	while (len--  0)
 		wchar = (wchar  8) | (*s1++  0xff);
-	wchar = (wchar  ~ei-mask) | ei-bits[cs];
+	if (wchar != (wchar  ~ei-mask) | ei-bits[cs])
+		goto encoding_error;
 
 	psenc-chlen = 0;
 	if (pwc)



CVS commit: src/lib/libc/include

2014-01-16 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Jan 16 20:31:18 UTC 2014

Modified Files:
src/lib/libc/include: namespace.h

Log Message:
namespace protection for the new err functions


To generate a diff of this commit:
cvs rdiff -u -r1.171 -r1.172 src/lib/libc/include/namespace.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/include/namespace.h
diff -u src/lib/libc/include/namespace.h:1.171 src/lib/libc/include/namespace.h:1.172
--- src/lib/libc/include/namespace.h:1.171	Thu Jan 16 14:16:42 2014
+++ src/lib/libc/include/namespace.h	Thu Jan 16 15:31:18 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: namespace.h,v 1.171 2014/01/16 19:16:42 joerg Exp $	*/
+/*	$NetBSD: namespace.h,v 1.172 2014/01/16 20:31:18 christos Exp $	*/
 
 /*-
  * Copyright (c) 1997-2004 The NetBSD Foundation, Inc.
@@ -44,6 +44,7 @@
 #define err		_err
 #define errc		_errc
 #define errx		_errx
+#define errc		_errc
 #ifdef _REENTRANT
 #define fileno		_fileno
 #endif /* _REENTRANT */
@@ -83,12 +84,15 @@
 #define verr		_verr
 #define verrc		_verrc
 #define verrx		_verrx
+#define verrc		_verrc
 #define vwarn		_vwarn
 #define vwarnc		_vwarnc
 #define vwarnx		_vwarnx
+#define vwarnc		_vwarnc
 #define warn		_warn
 #define warnc		_warnc
 #define warnx		_warnx
+#define warnc		_warnc
 
 #ifdef __weak_alias
 #define MD2Data			_MD2Data



CVS commit: src/lib/libc

2014-01-16 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Jan 16 20:31:43 UTC 2014

Modified Files:
src/lib/libc/compat/gen: Makefile.inc
src/lib/libc/gdtoa: Makefile.inc
src/lib/libc/gen: Makefile.inc
src/lib/libc/inet: Makefile.inc
src/lib/libc/resolv: Makefile.inc
src/lib/libc/stdio: Makefile.inc
src/lib/libc/sys: Makefile.inc
src/lib/libc/time: Makefile.inc
Removed Files:
src/lib/libc/compat/gen: compat__sys_errlist.c compat__sys_nerr.c
compat__sys_siglist.c
src/lib/libc/gdtoa: _strtof.c _strtold.c
src/lib/libc/gen: _err.c _errc.c _errx.c _sysconf.c _verr.c _verrc.c
_verrx.c _vwarn.c _vwarnc.c _vwarnx.c _warn.c _warnc.c _warnx.c
src/lib/libc/inet: _inet_aton.c _inet_pton.c
src/lib/libc/resolv: __dn_comp.c __res_close.c __res_send.c
src/lib/libc/stdio: _fileno.c _fseeko.c _ftello.c
src/lib/libc/sys: _brk.c _fork.c _getcontext.c _pipe.c _sbrk.c
src/lib/libc/time: _daylight.c

Log Message:
soon is now. Remove all __indr_reference crap.


To generate a diff of this commit:
cvs rdiff -u -r1.16 -r1.17 src/lib/libc/compat/gen/Makefile.inc
cvs rdiff -u -r1.1 -r0 src/lib/libc/compat/gen/compat__sys_errlist.c \
src/lib/libc/compat/gen/compat__sys_nerr.c \
src/lib/libc/compat/gen/compat__sys_siglist.c
cvs rdiff -u -r1.9 -r1.10 src/lib/libc/gdtoa/Makefile.inc
cvs rdiff -u -r1.3 -r0 src/lib/libc/gdtoa/_strtof.c
cvs rdiff -u -r1.2 -r0 src/lib/libc/gdtoa/_strtold.c
cvs rdiff -u -r1.186 -r1.187 src/lib/libc/gen/Makefile.inc
cvs rdiff -u -r1.12 -r0 src/lib/libc/gen/_err.c src/lib/libc/gen/_errx.c
cvs rdiff -u -r1.1 -r0 src/lib/libc/gen/_errc.c src/lib/libc/gen/_verrc.c \
src/lib/libc/gen/_vwarnc.c src/lib/libc/gen/_warnc.c
cvs rdiff -u -r1.6 -r0 src/lib/libc/gen/_sysconf.c
cvs rdiff -u -r1.11 -r0 src/lib/libc/gen/_verr.c src/lib/libc/gen/_verrx.c \
src/lib/libc/gen/_vwarn.c src/lib/libc/gen/_vwarnx.c \
src/lib/libc/gen/_warn.c src/lib/libc/gen/_warnx.c
cvs rdiff -u -r1.1 -r1.2 src/lib/libc/inet/Makefile.inc
cvs rdiff -u -r1.4 -r0 src/lib/libc/inet/_inet_aton.c \
src/lib/libc/inet/_inet_pton.c
cvs rdiff -u -r1.4 -r1.5 src/lib/libc/resolv/Makefile.inc
cvs rdiff -u -r1.5 -r0 src/lib/libc/resolv/__dn_comp.c
cvs rdiff -u -r1.4 -r0 src/lib/libc/resolv/__res_close.c \
src/lib/libc/resolv/__res_send.c
cvs rdiff -u -r1.42 -r1.43 src/lib/libc/stdio/Makefile.inc
cvs rdiff -u -r1.5 -r0 src/lib/libc/stdio/_fileno.c \
src/lib/libc/stdio/_fseeko.c src/lib/libc/stdio/_ftello.c
cvs rdiff -u -r1.221 -r1.222 src/lib/libc/sys/Makefile.inc
cvs rdiff -u -r1.6 -r0 src/lib/libc/sys/_brk.c src/lib/libc/sys/_sbrk.c
cvs rdiff -u -r1.5 -r0 src/lib/libc/sys/_fork.c \
src/lib/libc/sys/_getcontext.c
cvs rdiff -u -r1.7 -r0 src/lib/libc/sys/_pipe.c
cvs rdiff -u -r1.17 -r1.18 src/lib/libc/time/Makefile.inc
cvs rdiff -u -r1.4 -r0 src/lib/libc/time/_daylight.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/compat/gen/Makefile.inc
diff -u src/lib/libc/compat/gen/Makefile.inc:1.16 src/lib/libc/compat/gen/Makefile.inc:1.17
--- src/lib/libc/compat/gen/Makefile.inc:1.16	Wed Oct 24 18:10:52 2012
+++ src/lib/libc/compat/gen/Makefile.inc	Thu Jan 16 15:31:42 2014
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile.inc,v 1.16 2012/10/24 22:10:52 christos Exp $
+#	$NetBSD: Makefile.inc,v 1.17 2014/01/16 20:31:42 christos Exp $
 
 .PATH: ${COMPATDIR}/gen
 SRCS+=compat_errlist.c compat_fts.c compat___fts13.c compat___fts30.c \
@@ -6,7 +6,6 @@ SRCS+=compat_errlist.c compat_fts.c comp
 compat_opendir.c compat_readdir.c compat__readdir_unlocked30.c \
 compat_scandir.c compat_siglist.c compat_signame.c compat_sigsetops.c \
 compat_times.c compat_timezone.c compat_unvis.c compat_utmpx.c \
-compat__sys_errlist.c compat__sys_nerr.c compat__sys_siglist.c \
 compat_time.c compat_utime.c compat_devname.c compat_alphasort.c \
 compat_getpwent.c compat___fts32.c compat_utmp.c compat___fts50.c \
 compat___unvis13.c compat_syslog.c compat_alloca.c

Index: src/lib/libc/gdtoa/Makefile.inc
diff -u src/lib/libc/gdtoa/Makefile.inc:1.9 src/lib/libc/gdtoa/Makefile.inc:1.10
--- src/lib/libc/gdtoa/Makefile.inc:1.9	Fri Apr 19 16:18:33 2013
+++ src/lib/libc/gdtoa/Makefile.inc	Thu Jan 16 15:31:42 2014
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile.inc,v 1.9 2013/04/19 20:18:33 joerg Exp $
+#	$NetBSD: Makefile.inc,v 1.10 2014/01/16 20:31:42 christos Exp $
 
 # gdtoa sources
 .PATH: ${.CURDIR}/gdtoa
@@ -36,10 +36,6 @@ SRCS+=	dmisc.c \
 	smisc.c strtodg.c sum.c \
 	ulp.c
 
-# wrappers
-SRCS+=	_strtof.c _strtold.c
-#SRCS+=	_hdtoa.c _ldtoa.c
-
 # XXX no hexadecimal floating-point string conversion for VAX FP yet
 .if ${MACHINE_ARCH} != vax
 SRCS+=	strtord.c

Index: src/lib/libc/net/gethnamaddr.c
diff -u src/lib/libc/net/gethnamaddr.c:1.85 src/lib/libc/net/gethnamaddr.c:1.86
--- src/lib/libc/net/gethnamaddr.c:1.85	Sat Dec 21 21:45:16 2013
+++ src/lib/libc/net/gethnamaddr.c	Thu Jan 16 15:59:21 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: gethnamaddr.c,v 1.85 2013/12/22 02:45:16 christos Exp $	*/
+/*	$NetBSD: gethnamaddr.c,v 1.86 2014/01/16 20:59:21 christos Exp $	*/
 
 /*
  * ++Copyright++ 1985, 1988, 1993
@@ -57,7 +57,7 @@
 static char sccsid[] = @(#)gethostnamadr.c	8.1 (Berkeley) 6/4/93;
 static char rcsid[] = Id: gethnamaddr.c,v 8.21 1997/06/01 20:34:37 vixie Exp ;
 #else
-__RCSID($NetBSD: gethnamaddr.c,v 1.85 2013/12/22 02:45:16 christos Exp $);
+__RCSID($NetBSD: gethnamaddr.c,v 1.86 2014/01/16 20:59:21 christos Exp $);
 #endif
 #endif /* LIBC_SCCS and not lint */
 
@@ -108,6 +108,20 @@ __weak_alias(gethostent,_gethostent)
 #define maybe_hnok(res, hn) maybe_ok((res), (hn), res_hnok)
 #define maybe_dnok(res, dn) maybe_ok((res), (dn), res_dnok)
 
+#define grow(arr, siz) do {			\
+	void *xptr = realloc(arr, siz + 10); 	\
+	if (xptr == NULL)			\
+		goto nospc;			\
+	arr = xptr;\
+	siz += 10;\
+} while (/*CONSTCOND*/0)
+
+#define setup(arr, siz) do {			\
+	arr = malloc(siz = 10); 		\
+	if (arr == NULL)			\
+		goto nospc;			\
+} while (/*CONSTCOND*/0)
+
 
 static const char AskedForGot[] =
 gethostby*.getanswer: asked for \%s\, got \%s\;
@@ -209,7 +223,8 @@ getanswer(const querybuf *answer, int an
 	int haveanswer, had_error;
 	int toobig = 0;
 	char tbuf[MAXDNAME];
-	char *aliases[MAXALIASES];
+	char **aliases;
+	size_t maxaliases;
 	char *addr_ptrs[MAXADDRS];
 	const char *tname;
 	int (*name_ok)(const char *);
@@ -231,6 +246,8 @@ getanswer(const querybuf *answer, int an
 	default:
 		return NULL;	/* XXX should be abort(); */
 	}
+
+	setup(aliases, maxaliases);
 	/*
 	 * find first satisfactory answer
 	 */
@@ -290,8 +307,8 @@ getanswer(const querybuf *answer, int an
 			continue;		/* XXX - had_error++ ? */
 		}
 		if ((qtype == T_A || qtype == T_)  type == T_CNAME) {
-			if (ap = aliases[MAXALIASES-1])
-continue;
+			if (ap = aliases[maxaliases - 1])
+grow(aliases, maxaliases);
 			n = dn_expand(answer-buf, eom, cp, tbuf,
 			(int)sizeof tbuf);
 			if ((n  0) || !maybe_ok(res, tbuf, name_ok)) {
@@ -369,10 +386,11 @@ getanswer(const querybuf *answer, int an
 goto no_recovery;
 			if (!haveanswer)
 hent-h_name = bp;
-			else if (ap  aliases[MAXALIASES-1])
+			else {
+if (ap = aliases[maxaliases - 1])
+	grow(aliases, maxaliases);
 *ap++ = bp;
-			else
-n = -1;
+			}
 			if (n != -1) {
 n = (int)strlen(bp) + 1;	/* for the \0 */
 if (n = MAXHOSTNAMELEN) {
@@ -474,6 +492,7 @@ getanswer(const querybuf *answer, int an
 		goto success;
 	}
 no_recovery:
+	free(aliases);
 	*he = NO_RECOVERY;
 	return NULL;
 success:
@@ -484,6 +503,7 @@ success:
 		goto nospc;
 	hent-h_aliases = (void *)bp;
 	memcpy(bp, aliases, qlen);
+	free(aliases);
 
 	bp += qlen;
 	n = (int)(hap - addr_ptrs);
@@ -495,6 +515,7 @@ success:
 	*he = NETDB_SUCCESS;
 	return hent;
 nospc:
+	free(aliases);
 	errno = ENOSPC;
 	*he = NETDB_INTERNAL;
 	return NULL;
@@ -725,7 +746,8 @@ gethostent_r(FILE *hf, struct hostent *h
 	char *cp, **q;
 	int af, len;
 	size_t llen, anum;
-	char *aliases[MAXALIASES];
+	char **aliases;
+	size_t maxaliases;
 	struct in6_addr host_addr;
 
 	if (hf == NULL) {
@@ -733,8 +755,10 @@ gethostent_r(FILE *hf, struct hostent *h
 		errno = EINVAL;
 		return NULL;
 	}
+	setup(aliases, maxaliases);
  again:
 	if ((p = fgetln(hf, llen)) == NULL) {
+		free(aliases);
 		*he = HOST_NOT_FOUND;
 		return NULL;
 	}
@@ -755,7 +779,7 @@ gethostent_r(FILE *hf, struct hostent *h
 	} else if (inet_pton(AF_INET, p, host_addr)  0) {
 		res_state res = __res_get_state();
 		if (res == NULL)
-			return NULL;
+			goto nospc;
 		if (res-options  RES_USE_INET6) {
 			map_v4v6_address(buf, buf);
 			af = AF_INET6;
@@ -784,8 +808,8 @@ gethostent_r(FILE *hf, struct hostent *h
 			cp++;
 			continue;
 		}
-		if (q = aliases[__arraycount(aliases)])
-			goto nospc;
+		if (q = aliases[maxaliases - 1])
+			grow(aliases, maxaliases);
 		*q++ = cp;
 		if ((cp = strpbrk(cp,  \t)) != NULL)
 			*cp++ = '\0';
@@ -805,8 +829,10 @@ gethostent_r(FILE *hf, struct hostent *h
 	hent-h_aliases[anum] = NULL;
 
 	*he = NETDB_SUCCESS;
+	free(aliases);
 	return hent;
 nospc:
+	free(aliases);
 	errno = ENOSPC;
 	*he = NETDB_INTERNAL;
 	return NULL;
@@ -1080,7 +1106,8 @@ static struct hostent *
 _yp_hostent(char *line, int af, struct getnamaddr *info)
 {
 	struct in6_addr 

CVS commit: src/lib/libc/include

2014-01-16 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Jan 16 21:02:30 UTC 2014

Modified Files:
src/lib/libc/include: namespace.h

Log Message:
remove dups


To generate a diff of this commit:
cvs rdiff -u -r1.172 -r1.173 src/lib/libc/include/namespace.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/include/namespace.h
diff -u src/lib/libc/include/namespace.h:1.172 src/lib/libc/include/namespace.h:1.173
--- src/lib/libc/include/namespace.h:1.172	Thu Jan 16 15:31:18 2014
+++ src/lib/libc/include/namespace.h	Thu Jan 16 16:02:30 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: namespace.h,v 1.172 2014/01/16 20:31:18 christos Exp $	*/
+/*	$NetBSD: namespace.h,v 1.173 2014/01/16 21:02:30 christos Exp $	*/
 
 /*-
  * Copyright (c) 1997-2004 The NetBSD Foundation, Inc.
@@ -44,7 +44,6 @@
 #define err		_err
 #define errc		_errc
 #define errx		_errx
-#define errc		_errc
 #ifdef _REENTRANT
 #define fileno		_fileno
 #endif /* _REENTRANT */
@@ -84,15 +83,12 @@
 #define verr		_verr
 #define verrc		_verrc
 #define verrx		_verrx
-#define verrc		_verrc
 #define vwarn		_vwarn
 #define vwarnc		_vwarnc
 #define vwarnx		_vwarnx
-#define vwarnc		_vwarnc
 #define warn		_warn
 #define warnc		_warnc
 #define warnx		_warnx
-#define warnc		_warnc
 
 #ifdef __weak_alias
 #define MD2Data			_MD2Data



CVS commit: src

2014-01-16 Thread Matt Thomas
Module Name:src
Committed By:   matt
Date:   Thu Jan 16 21:48:41 UTC 2014

Modified Files:
src/lib/libarch/arm: arm_sync_icache.2 arm_sync_icache.c
src/sys/arch/arm/include: sysarch.h

Log Message:
Use uintptr_t  size_t instead of u_int and int for arm_sync_icache.


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.6 src/lib/libarch/arm/arm_sync_icache.2
cvs rdiff -u -r1.1 -r1.2 src/lib/libarch/arm/arm_sync_icache.c
cvs rdiff -u -r1.10 -r1.11 src/sys/arch/arm/include/sysarch.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libarch/arm/arm_sync_icache.2
diff -u src/lib/libarch/arm/arm_sync_icache.2:1.5 src/lib/libarch/arm/arm_sync_icache.2:1.6
--- src/lib/libarch/arm/arm_sync_icache.2:1.5	Fri Feb 13 09:56:47 2004
+++ src/lib/libarch/arm/arm_sync_icache.2	Thu Jan 16 21:48:41 2014
@@ -1,4 +1,4 @@
-.\	$NetBSD: arm_sync_icache.2,v 1.5 2004/02/13 09:56:47 wiz Exp $
+.\	$NetBSD: arm_sync_icache.2,v 1.6 2014/01/16 21:48:41 matt Exp $
 .\
 .\ Copyright (c) 1996 Mark Brinicombe
 .\ All rights reserved.
@@ -30,7 +30,7 @@
 .\ OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 .\ SUCH DAMAGE.
 .\
-.Dd March 29, 2002
+.Dd January 17, 2014
 .Dt ARM_SYNC_ICACHE 2 arm
 .Os
 .Sh NAME
@@ -41,7 +41,7 @@
 .Sh SYNOPSIS
 .In machine/sysarch.h
 .Ft int
-.Fn arm_sync_icache u_int addr int len
+.Fn arm_sync_icache uintptr_t addr size_t len
 .Sh DESCRIPTION
 .Fn arm_sync_icache
 will make sure that all the entries in the processor instruction cache

Index: src/lib/libarch/arm/arm_sync_icache.c
diff -u src/lib/libarch/arm/arm_sync_icache.c:1.1 src/lib/libarch/arm/arm_sync_icache.c:1.2
--- src/lib/libarch/arm/arm_sync_icache.c:1.1	Sat Mar 30 06:24:34 2002
+++ src/lib/libarch/arm/arm_sync_icache.c	Thu Jan 16 21:48:41 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: arm_sync_icache.c,v 1.1 2002/03/30 06:24:34 thorpej Exp $	*/
+/*	$NetBSD: arm_sync_icache.c,v 1.2 2014/01/16 21:48:41 matt Exp $	*/
 
 /*
  * Copyright (c) 1996 Mark Brinicombe.
@@ -38,9 +38,7 @@
 #include machine/sysarch.h
 
 int
-arm_sync_icache(addr, len)
-	u_int addr;
-	int len;
+arm_sync_icache(uintptr_t addr, size_t len)
 {
 	struct arm_sync_icache_args p;
 

Index: src/sys/arch/arm/include/sysarch.h
diff -u src/sys/arch/arm/include/sysarch.h:1.10 src/sys/arch/arm/include/sysarch.h:1.11
--- src/sys/arch/arm/include/sysarch.h:1.10	Fri Feb  1 15:23:11 2013
+++ src/sys/arch/arm/include/sysarch.h	Thu Jan 16 21:48:41 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: sysarch.h,v 1.10 2013/02/01 15:23:11 matt Exp $	*/
+/*	$NetBSD: sysarch.h,v 1.11 2014/01/16 21:48:41 matt Exp $	*/
 
 /*
  * Copyright (c) 1996-1997 Mark Brinicombe.
@@ -70,7 +70,7 @@ struct arm_unaligned_faults_args {
 
 #ifndef _KERNEL
 __BEGIN_DECLS
-int	arm_sync_icache(u_int addr, int len);
+int	arm_sync_icache(uintptr_t, size_t);
 int	arm_drain_writebuf(void);
 int	sysarch(int, void *);
 __END_DECLS



CVS commit: src/tests/crypto/opencrypto

2014-01-16 Thread Paul Goyette
Module Name:src
Committed By:   pgoyette
Date:   Thu Jan 16 22:06:45 UTC 2014

Modified Files:
src/tests/crypto/opencrypto: h_xcbcmac.c

Log Message:
Since sizeof() is unsigned, use an unsigned int for the loop index.

Fixes latest build break.


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 src/tests/crypto/opencrypto/h_xcbcmac.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/tests/crypto/opencrypto/h_xcbcmac.c
diff -u src/tests/crypto/opencrypto/h_xcbcmac.c:1.2 src/tests/crypto/opencrypto/h_xcbcmac.c:1.3
--- src/tests/crypto/opencrypto/h_xcbcmac.c:1.2	Thu Jan 16 18:09:55 2014
+++ src/tests/crypto/opencrypto/h_xcbcmac.c	Thu Jan 16 22:06:45 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: h_xcbcmac.c,v 1.2 2014/01/16 18:09:55 pgoyette Exp $ */
+/* $NetBSD: h_xcbcmac.c,v 1.3 2014/01/16 22:06:45 pgoyette Exp $ */
 
 /*-
  * Copyright (c) 2014 The NetBSD Foundation, Inc.
@@ -72,7 +72,8 @@ const struct {
 int
 main(void)
 {
-	int fd, res, i;
+	int fd, res;
+	unsigned int i;
 	struct session_op cs;
 	struct crypt_op co;
 	unsigned char buf[16];



CVS commit: src/lib/libc/compiler_rt

2014-01-16 Thread Matt Thomas
Module Name:src
Committed By:   matt
Date:   Thu Jan 16 23:05:51 UTC 2014

Modified Files:
src/lib/libc/compiler_rt: Makefile.inc

Log Message:
Don't build common quad routines if the platform is 64bit since they
will not be emitted by the compiler.


To generate a diff of this commit:
cvs rdiff -u -r1.4 -r1.5 src/lib/libc/compiler_rt/Makefile.inc

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/compiler_rt/Makefile.inc
diff -u src/lib/libc/compiler_rt/Makefile.inc:1.4 src/lib/libc/compiler_rt/Makefile.inc:1.5
--- src/lib/libc/compiler_rt/Makefile.inc:1.4	Wed Jan 15 21:20:53 2014
+++ src/lib/libc/compiler_rt/Makefile.inc	Thu Jan 16 23:05:51 2014
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile.inc,v 1.4 2014/01/15 21:20:53 joerg Exp $
+# $NetBSD: Makefile.inc,v 1.5 2014/01/16 23:05:51 matt Exp $
 
 COMPILER_RT_SRCDIR=	${NETBSDSRCDIR}/sys/external/bsd/compiler_rt/dist
 
@@ -58,30 +58,20 @@ GENERIC_SRCS+= \
 .endif
 
 GENERIC_SRCS+= \
-	absvdi2.c \
 	absvsi2.c \
 	absvti2.c \
-	addvdi3.c \
 	addvsi3.c \
 	addvti3.c \
-	ashldi3.c \
 	ashlti3.c \
-	ashrdi3.c \
 	ashrti3.c \
-	clzdi2.c \
 	clzsi2.c \
 	clzti2.c \
-	cmpdi2.c \
 	cmpti2.c \
-	ctzdi2.c \
 	ctzsi2.c \
 	ctzti2.c \
-	divdi3.c \
-	divmoddi4.c \
 	divmodsi4.c \
 	divsi3.c \
 	divti3.c \
-	ffsdi2.c \
 	ffsti2.c \
 	fixunsdfdi.c \
 	fixunsdfsi.c \
@@ -109,53 +99,69 @@ GENERIC_SRCS+= \
 	floatuntisf.c \
 	floatuntixf.c \
 	int_util.c \
-	lshrdi3.c \
 	lshrti3.c \
-	moddi3.c \
 	modsi3.c \
 	modti3.c \
 	muldc3.c \
-	muldi3.c \
-	mulodi4.c \
 	mulosi4.c \
 	muloti4.c \
 	multi3.c \
-	mulvdi3.c \
 	mulvsi3.c \
 	mulvti3.c \
 	negdf2.c \
-	negdi2.c \
 	negsf2.c \
 	negti2.c \
-	negvdi2.c \
 	negvsi2.c \
 	negvti2.c \
-	paritydi2.c \
 	paritysi2.c \
 	parityti2.c \
-	popcountdi2.c \
 	popcountsi2.c \
 	popcountti2.c \
 	powidf2.c \
 	powisf2.c \
 	powitf2.c \
 	powixf2.c \
-	subvdi3.c \
 	subvsi3.c \
 	subvti3.c \
-	ucmpdi2.c \
 	ucmpti2.c \
-	udivdi3.c \
-	udivmoddi4.c \
 	udivmodsi4.c \
 	udivmodti4.c \
 	udivsi3.c \
 	udivti3.c \
-	umoddi3.c \
 	umodsi3.c \
 	umodti3.c
 
 GENERIC_SRCS+= \
+	absvdi2.c \
+	addvdi3.c \
+	clzdi2.c \
+	ctzdi2.c \
+	ffsdi2.c \
+	mulodi4.c \
+	mulvdi3.c \
+	negvdi2.c \
+	paritydi2.c \
+	popcountdi2.c \
+	subvdi3.c
+
+.if empty(MACHINE_ARCH:M*64*)  ${MACHINE_ARCH} != alpha
+GENERIC_SRCS+= \
+	cmpdi2.c \
+	ashldi3.c \
+	ashrdi3.c \
+	divdi3.c \
+	divmoddi4.c \
+	lshrdi3.c \
+	moddi3.c \
+	muldi3.c \
+	negdi2.c \
+	ucmpdi2.c \
+	udivdi3.c \
+	udivmoddi4.c \
+	umoddi3.c
+.endif
+
+GENERIC_SRCS+= \
 	GCDAProfiling.c \
 	PGOProfiling.c
 



CVS commit: src/external/bsd/file/dist/src

2014-01-16 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Thu Jan 16 23:35:54 UTC 2014

Modified Files:
src/external/bsd/file/dist/src: file.c

Log Message:
Mark some more dead functions.


To generate a diff of this commit:
cvs rdiff -u -r1.1.1.6 -r1.2 src/external/bsd/file/dist/src/file.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/file/dist/src/file.c
diff -u src/external/bsd/file/dist/src/file.c:1.1.1.6 src/external/bsd/file/dist/src/file.c:1.2
--- src/external/bsd/file/dist/src/file.c:1.1.1.6	Sun Dec  1 19:28:17 2013
+++ src/external/bsd/file/dist/src/file.c	Thu Jan 16 23:35:54 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: file.c,v 1.1.1.6 2013/12/01 19:28:17 christos Exp $	*/
+/*	$NetBSD: file.c,v 1.2 2014/01/16 23:35:54 joerg Exp $	*/
 
 /*
  * Copyright (c) Ian F. Darwin 1986-1995.
@@ -37,7 +37,7 @@
 #if 0
 FILE_RCSID(@(#)$File: file.c,v 1.152 2013/06/26 14:46:54 christos Exp $)
 #else
-__RCSID($NetBSD: file.c,v 1.1.1.6 2013/12/01 19:28:17 christos Exp $);
+__RCSID($NetBSD: file.c,v 1.2 2014/01/16 23:35:54 joerg Exp $);
 #endif
 #endif	/* lint */
 
@@ -127,9 +127,9 @@ private const struct {
 
 private char *progname;		/* used throughout 		*/
 
-private void usage(void);
+private void usage(void) __dead;
 private void docprint(const char *);
-private void help(void);
+private void help(void) __dead;
 
 private int unwrap(struct magic_set *, const char *);
 private int process(struct magic_set *ms, const char *, int);



CVS commit: src/external/bsd/file/dist/src

2014-01-16 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Thu Jan 16 23:36:52 UTC 2014

Modified Files:
src/external/bsd/file/dist/src: file.c

Log Message:
Only use __dead if it exists.


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 src/external/bsd/file/dist/src/file.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/file/dist/src/file.c
diff -u src/external/bsd/file/dist/src/file.c:1.2 src/external/bsd/file/dist/src/file.c:1.3
--- src/external/bsd/file/dist/src/file.c:1.2	Thu Jan 16 23:35:54 2014
+++ src/external/bsd/file/dist/src/file.c	Thu Jan 16 23:36:52 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: file.c,v 1.2 2014/01/16 23:35:54 joerg Exp $	*/
+/*	$NetBSD: file.c,v 1.3 2014/01/16 23:36:52 joerg Exp $	*/
 
 /*
  * Copyright (c) Ian F. Darwin 1986-1995.
@@ -37,7 +37,7 @@
 #if 0
 FILE_RCSID(@(#)$File: file.c,v 1.152 2013/06/26 14:46:54 christos Exp $)
 #else
-__RCSID($NetBSD: file.c,v 1.2 2014/01/16 23:35:54 joerg Exp $);
+__RCSID($NetBSD: file.c,v 1.3 2014/01/16 23:36:52 joerg Exp $);
 #endif
 #endif	/* lint */
 
@@ -127,9 +127,15 @@ private const struct {
 
 private char *progname;		/* used throughout 		*/
 
-private void usage(void) __dead;
+#ifdef __dead
+__dead
+#endif
+private void usage(void);
 private void docprint(const char *);
-private void help(void) __dead;
+#ifdef __dead
+__dead
+#endif
+private void help(void);
 
 private int unwrap(struct magic_set *, const char *);
 private int process(struct magic_set *ms, const char *, int);



CVS commit: src/tests/crypto/opencrypto

2014-01-16 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Thu Jan 16 23:56:04 UTC 2014

Modified Files:
src/tests/crypto/opencrypto: h_xcbcmac.c

Log Message:
Use __arraycount and size_t as the format strings are wrong anyway.


To generate a diff of this commit:
cvs rdiff -u -r1.3 -r1.4 src/tests/crypto/opencrypto/h_xcbcmac.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/tests/crypto/opencrypto/h_xcbcmac.c
diff -u src/tests/crypto/opencrypto/h_xcbcmac.c:1.3 src/tests/crypto/opencrypto/h_xcbcmac.c:1.4
--- src/tests/crypto/opencrypto/h_xcbcmac.c:1.3	Thu Jan 16 22:06:45 2014
+++ src/tests/crypto/opencrypto/h_xcbcmac.c	Thu Jan 16 23:56:04 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: h_xcbcmac.c,v 1.3 2014/01/16 22:06:45 pgoyette Exp $ */
+/* $NetBSD: h_xcbcmac.c,v 1.4 2014/01/16 23:56:04 joerg Exp $ */
 
 /*-
  * Copyright (c) 2014 The NetBSD Foundation, Inc.
@@ -73,7 +73,7 @@ int
 main(void)
 {
 	int fd, res;
-	unsigned int i;
+	size_t i;
 	struct session_op cs;
 	struct crypt_op co;
 	unsigned char buf[16];
@@ -89,7 +89,7 @@ main(void)
 	if (res  0)
 		err(1, CIOCGSESSION);
 
-	for (i = 0; i  sizeof(tests)/sizeof(tests[0]); i++) {
+	for (i = 0; i  __arraycount(tests); i++) {
 		memset(co, 0, sizeof(co));
 		memset(buf, 0, sizeof(buf));
 		if (tests[i].len == sizeof(plaintx))
@@ -101,9 +101,9 @@ main(void)
 		co.mac = buf;
 		res = ioctl(fd, CIOCCRYPT, co);
 		if (res  0)
-			err(1, CIOCCRYPT test %d, i);
+			err(1, CIOCCRYPT test %zu, i);
 		if (memcmp(buf, tests[i].mac, sizeof(tests[i].mac)))
-			errx(1, verification failed test %d, i);
+			errx(1, verification failed test %zu, i);
 	}
 	return 0;
 }



CVS commit: src/distrib/sets/lists

2014-01-16 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Fri Jan 17 00:13:13 UTC 2014

Modified Files:
src/distrib/sets/lists/base: ad.arm ad.mips md.amd64 md.sparc64
src/distrib/sets/lists/debug: ad.arm ad.mips md.amd64 md.sparc64 shl.mi

Log Message:
Finish updating set lists for libc minor bump.


To generate a diff of this commit:
cvs rdiff -u -r1.31 -r1.32 src/distrib/sets/lists/base/ad.arm
cvs rdiff -u -r1.27 -r1.28 src/distrib/sets/lists/base/ad.mips
cvs rdiff -u -r1.221 -r1.222 src/distrib/sets/lists/base/md.amd64
cvs rdiff -u -r1.208 -r1.209 src/distrib/sets/lists/base/md.sparc64
cvs rdiff -u -r1.22 -r1.23 src/distrib/sets/lists/debug/ad.arm
cvs rdiff -u -r1.17 -r1.18 src/distrib/sets/lists/debug/ad.mips
cvs rdiff -u -r1.39 -r1.40 src/distrib/sets/lists/debug/md.amd64
cvs rdiff -u -r1.40 -r1.41 src/distrib/sets/lists/debug/md.sparc64
cvs rdiff -u -r1.46 -r1.47 src/distrib/sets/lists/debug/shl.mi

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/base/ad.arm
diff -u src/distrib/sets/lists/base/ad.arm:1.31 src/distrib/sets/lists/base/ad.arm:1.32
--- src/distrib/sets/lists/base/ad.arm:1.31	Sat Jan 11 18:38:00 2014
+++ src/distrib/sets/lists/base/ad.arm	Fri Jan 17 00:13:13 2014
@@ -1,4 +1,4 @@
-# $NetBSD: ad.arm,v 1.31 2014/01/11 18:38:00 christos Exp $
+# $NetBSD: ad.arm,v 1.32 2014/01/17 00:13:13 riz Exp $
 ./lib/oabi	base-compat-shlib	compat
 ./lib/oabi/npf	base-npf-shlib		compat
 ./lib/oabi/npf/ext_log.so			base-npf-shlib		compat,pic
@@ -92,7 +92,7 @@
 ./usr/lib/oabi/libc++.so.1			base-compat-shlib	compat,pic,libcxx
 ./usr/lib/oabi/libc++.so.1.0			base-compat-shlib	compat,pic,libcxx
 ./usr/lib/oabi/libc.so.12			base-compat-shlib	compat,pic
-./usr/lib/oabi/libc.so.12.188			base-compat-shlib	compat,pic
+./usr/lib/oabi/libc.so.12.189			base-compat-shlib	compat,pic
 ./usr/lib/oabi/libc_vfp.so.0			base-compat-shlib	compat,pic
 ./usr/lib/oabi/libc_vfp.so.0.0			base-compat-shlib	compat,pic
 ./usr/lib/oabi/libcom_err.so.7			base-compat-shlib	compat,pic,kerberos

Index: src/distrib/sets/lists/base/ad.mips
diff -u src/distrib/sets/lists/base/ad.mips:1.27 src/distrib/sets/lists/base/ad.mips:1.28
--- src/distrib/sets/lists/base/ad.mips:1.27	Sat Jan 11 18:38:00 2014
+++ src/distrib/sets/lists/base/ad.mips	Fri Jan 17 00:13:13 2014
@@ -1,4 +1,4 @@
-# $NetBSD: ad.mips,v 1.27 2014/01/11 18:38:00 christos Exp $
+# $NetBSD: ad.mips,v 1.28 2014/01/17 00:13:13 riz Exp $
 ./lib/64	base-compat-shlib	compat,arch64
 ./lib/64/npf	base-npf-shlib		compat,arch64
 ./lib/64/npf/ext_log.sobase-npf-shlib		compat,pic,arch64
@@ -94,7 +94,7 @@
 ./usr/lib/64/libc++.so.1			base-compat-shlib	compat,pic,libcxx,arch64
 ./usr/lib/64/libc++.so.1.0			base-compat-shlib	compat,pic,libcxx,arch64
 ./usr/lib/64/libc.so.12base-compat-shlib	compat,pic,arch64
-./usr/lib/64/libc.so.12.188			base-compat-shlib	compat,pic,arch64
+./usr/lib/64/libc.so.12.189			base-compat-shlib	compat,pic,arch64
 ./usr/lib/64/libcom_err.so.7			base-compat-shlib	compat,pic,kerberos,arch64
 ./usr/lib/64/libcom_err.so.7.0			base-compat-shlib	compat,pic,kerberos,arch64
 ./usr/lib/64/libcrypt.so.1			base-compat-shlib	compat,pic,arch64
@@ -434,7 +434,7 @@
 ./usr/lib/o32/libc++.so.1			base-compat-shlib	compat,pic,libcxx,arch64
 ./usr/lib/o32/libc++.so.1.0			base-compat-shlib	compat,pic,libcxx,arch64
 ./usr/lib/o32/libc.so.12			base-compat-shlib	compat,pic,arch64
-./usr/lib/o32/libc.so.12.188			base-compat-shlib	compat,pic,arch64
+./usr/lib/o32/libc.so.12.189			base-compat-shlib	compat,pic,arch64
 ./usr/lib/o32/libcom_err.so.7			base-compat-shlib	compat,pic,kerberos,arch64
 ./usr/lib/o32/libcom_err.so.7.0			base-compat-shlib	compat,pic,kerberos,arch64
 ./usr/lib/o32/libcrypt.so.1			base-compat-shlib	compat,pic,arch64

Index: src/distrib/sets/lists/base/md.amd64
diff -u src/distrib/sets/lists/base/md.amd64:1.221 src/distrib/sets/lists/base/md.amd64:1.222
--- src/distrib/sets/lists/base/md.amd64:1.221	Sat Jan 11 18:38:00 2014
+++ src/distrib/sets/lists/base/md.amd64	Fri Jan 17 00:13:13 2014
@@ -1,4 +1,4 @@
-# $NetBSD: md.amd64,v 1.221 2014/01/11 18:38:00 christos Exp $
+# $NetBSD: md.amd64,v 1.222 2014/01/17 00:13:13 riz Exp $
 ./dev/lms0	base-obsolete		obsolete
 ./dev/mms0	base-obsolete		obsolete
 ./lib/i386	base-compat-shlib		compat
@@ -86,7 +86,7 @@
 ./usr/lib/i386/libc++.so.1			base-compat-shlib	compat,pic,libcxx
 ./usr/lib/i386/libc++.so.1.0			base-compat-shlib	compat,pic,libcxx
 ./usr/lib/i386/libc.so.12			base-compat-shlib	compat,pic
-./usr/lib/i386/libc.so.12.188			base-compat-shlib	compat,pic
+./usr/lib/i386/libc.so.12.189			base-compat-shlib	compat,pic
 ./usr/lib/i386/libcom_err.so.7			base-compat-shlib	compat,pic,kerberos
 ./usr/lib/i386/libcom_err.so.7.0		base-compat-shlib	compat,pic,kerberos
 ./usr/lib/i386/libcrypt.so.1			base-compat-shlib	compat,pic

Index: src/distrib/sets/lists/base/md.sparc64
diff -u 

CVS commit: src/distrib/sets/lists/base

2014-01-16 Thread Jeff Rizzo
Module Name:src
Committed By:   riz
Date:   Fri Jan 17 00:00:05 UTC 2014

Modified Files:
src/distrib/sets/lists/base: shl.mi

Log Message:
Update setlists for libc minor bump.


To generate a diff of this commit:
cvs rdiff -u -r1.686 -r1.687 src/distrib/sets/lists/base/shl.mi

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/base/shl.mi
diff -u src/distrib/sets/lists/base/shl.mi:1.686 src/distrib/sets/lists/base/shl.mi:1.687
--- src/distrib/sets/lists/base/shl.mi:1.686	Tue Jan 14 17:18:43 2014
+++ src/distrib/sets/lists/base/shl.mi	Fri Jan 17 00:00:05 2014
@@ -1,4 +1,4 @@
-# $NetBSD: shl.mi,v 1.686 2014/01/14 17:18:43 pgoyette Exp $
+# $NetBSD: shl.mi,v 1.687 2014/01/17 00:00:05 riz Exp $
 #
 # Note:	Don't delete entries from here - mark them as obsolete instead,
 #	unless otherwise stated below.
@@ -15,7 +15,7 @@
 #
 ./lib/libc.so	base-sys-shlib		dynamicroot
 ./lib/libc.so.12base-sys-shlib		dynamicroot
-./lib/libc.so.12.188base-sys-shlib		dynamicroot
+./lib/libc.so.12.189base-sys-shlib		dynamicroot
 ./lib/libcrypt.sobase-sys-shlib		dynamicroot
 ./lib/libcrypt.so.1base-sys-shlib		dynamicroot
 ./lib/libcrypt.so.1.0base-sys-shlib		dynamicroot
@@ -197,7 +197,7 @@
 ./usr/lib/libc++.so.1.0base-sys-shlib		libcxx
 ./usr/lib/libc.sobase-sys-shlib
 ./usr/lib/libc.so.12base-sys-shlib
-./usr/lib/libc.so.12.188			base-sys-shlib
+./usr/lib/libc.so.12.189			base-sys-shlib
 ./usr/lib/libcdk.sobase-obsolete		obsolete
 ./usr/lib/libcom_err.sobase-krb5-shlib		kerberos
 ./usr/lib/libcom_err.so.7			base-krb5-shlib		kerberos



CVS commit: src/distrib/notes/common

2014-01-16 Thread Kenichi Hashimoto
Module Name:src
Committed By:   hkenken
Date:   Fri Jan 17 00:19:25 UTC 2014

Modified Files:
src/distrib/notes/common: main

Log Message:
added myself


To generate a diff of this commit:
cvs rdiff -u -r1.500 -r1.501 src/distrib/notes/common/main

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/notes/common/main
diff -u src/distrib/notes/common/main:1.500 src/distrib/notes/common/main:1.501
--- src/distrib/notes/common/main:1.500	Tue Jan  7 04:46:02 2014
+++ src/distrib/notes/common/main	Fri Jan 17 00:19:25 2014
@@ -1,4 +1,4 @@
-.\	$NetBSD: main,v 1.500 2014/01/07 04:46:02 pho Exp $
+.\	$NetBSD: main,v 1.501 2014/01/17 00:19:25 hkenken Exp $
 .\
 .\ Copyright (c) 1999-2012 The NetBSD Foundation, Inc.
 .\ All rights reserved.
@@ -1208,6 +1208,7 @@ If you're one of them, and would like to
 .It Ta Charles M. Hannum Ta Mt mycr...@netbsd.org
 .It Ta Yorick Hardy Ta Mt yha...@netbsd.org
 .It Ta Ben Harris Ta Mt bj...@netbsd.org
+.It Ta Kenichi Hashimoto Ta Mt hken...@netbsd.org
 .It Ta Eric Haszlakiewicz Ta Mt e...@netbsd.org
 .It Ta John Hawkinson Ta Mt jh...@netbsd.org
 .It Ta Emile Heitor Ta Mt i...@netbsd.org



CVS commit: src/sys/lib/libkern

2014-01-16 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Fri Jan 17 00:49:55 UTC 2014

Modified Files:
src/sys/lib/libkern: Makefile.compiler-rt

Log Message:
This is not libc, so don't check the libc arch macro.


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/sys/lib/libkern/Makefile.compiler-rt

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/lib/libkern/Makefile.compiler-rt
diff -u src/sys/lib/libkern/Makefile.compiler-rt:1.1 src/sys/lib/libkern/Makefile.compiler-rt:1.2
--- src/sys/lib/libkern/Makefile.compiler-rt:1.1	Tue Dec  3 16:15:22 2013
+++ src/sys/lib/libkern/Makefile.compiler-rt	Fri Jan 17 00:49:55 2014
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile.compiler-rt,v 1.1 2013/12/03 16:15:22 joerg Exp $
+# $NetBSD: Makefile.compiler-rt,v 1.2 2014/01/17 00:49:55 joerg Exp $
 
 COMPILER_RT_SRCDIR=	${NETBSDSRCDIR}/sys/external/bsd/compiler_rt/dist
 
@@ -81,7 +81,7 @@ GENERIC_SRCS+= \
 	umodti3.c
 
 .if ${MACHINE_CPU} == arm
-.  if !empty(LIBC_MACHINE_ARCH:Mearm*)
+.  if !empty(MACHINE_ARCH:Mearm*)
 GENERIC_SRCS+= \
 	aeabi_idivmod.S \
 	aeabi_ldivmod.S \



CVS commit: src/sys/rump

2014-01-16 Thread Antti Kantee
Module Name:src
Committed By:   pooka
Date:   Fri Jan 17 01:32:53 UTC 2014

Modified Files:
src/sys/rump/kern/lib/libcrypto: Makefile
src/sys/rump/librump/rumpkern: Makefile.rumpkern emul.c rump.c
rump_private.h
Added Files:
src/sys/rump/librump/rumpkern: hyperentropy.c
Removed Files:
src/sys/rump/librump/rumpkern: cprng_stub.c

Log Message:
Use subr_cprng.c instead of stub implementation.  Rijndael migrates from
rumpkern_crypto to rumpkern due to it being mandatory for cprng.


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 src/sys/rump/kern/lib/libcrypto/Makefile
cvs rdiff -u -r1.134 -r1.135 src/sys/rump/librump/rumpkern/Makefile.rumpkern
cvs rdiff -u -r1.8 -r0 src/sys/rump/librump/rumpkern/cprng_stub.c
cvs rdiff -u -r1.160 -r1.161 src/sys/rump/librump/rumpkern/emul.c
cvs rdiff -u -r0 -r1.1 src/sys/rump/librump/rumpkern/hyperentropy.c
cvs rdiff -u -r1.281 -r1.282 src/sys/rump/librump/rumpkern/rump.c
cvs rdiff -u -r1.78 -r1.79 src/sys/rump/librump/rumpkern/rump_private.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/rump/kern/lib/libcrypto/Makefile
diff -u src/sys/rump/kern/lib/libcrypto/Makefile:1.2 src/sys/rump/kern/lib/libcrypto/Makefile:1.3
--- src/sys/rump/kern/lib/libcrypto/Makefile:1.2	Tue Jan 14 17:05:50 2014
+++ src/sys/rump/kern/lib/libcrypto/Makefile	Fri Jan 17 01:32:53 2014
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.2 2014/01/14 17:05:50 pgoyette Exp $
+#	$NetBSD: Makefile,v 1.3 2014/01/17 01:32:53 pooka Exp $
 #
 
 .PATH:	${.CURDIR}/../../../../crypto/arc4\
@@ -27,7 +27,8 @@ SRCS+=	cast128.c
 SRCS+=	des_ecb.c des_setkey.c des_enc.c des_cbc.c des_module.c
 
 # rijndael
-SRCS+=	rijndael-alg-fst.c rijndael-api-fst.c rijndael.c
+# rijndael is in rumpkern due to it being used by cprng
+#SRCS+=	rijndael-alg-fst.c rijndael-api-fst.c rijndael.c
 
 # skipjack
 SRCS+=	skipjack.c

Index: src/sys/rump/librump/rumpkern/Makefile.rumpkern
diff -u src/sys/rump/librump/rumpkern/Makefile.rumpkern:1.134 src/sys/rump/librump/rumpkern/Makefile.rumpkern:1.135
--- src/sys/rump/librump/rumpkern/Makefile.rumpkern:1.134	Mon Dec  9 17:57:11 2013
+++ src/sys/rump/librump/rumpkern/Makefile.rumpkern	Fri Jan 17 01:32:53 2014
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile.rumpkern,v 1.134 2013/12/09 17:57:11 pooka Exp $
+#	$NetBSD: Makefile.rumpkern,v 1.135 2014/01/17 01:32:53 pooka Exp $
 #
 
 .include ${RUMPTOP}/Makefile.rump
@@ -12,6 +12,8 @@ LIB=		rump
 	${RUMPTOP}/../uvm	\
 	${RUMPTOP}/../conf	\
 	${RUMPTOP}/../dev	\
+	${RUMPTOP}/../crypto/nist_ctr_drbg			\
+	${RUMPTOP}/../crypto/rijndael\
 	${RUMPTOP}/../secmodel	\
 	${RUMPTOP}/../secmodel/suser\
 	${RUMPTOP}/../compat/common
@@ -21,7 +23,7 @@ LIB=		rump
 # 
 SRCS+=	rump.c rumpcopy.c cons.c emul.c intr.c lwproc.c klock.c	\
 	kobj_rename.c ltsleep.c scheduler.c			\
-	signals.c sleepq.c threads.c vm.c cprng_stub.c
+	signals.c sleepq.c threads.c vm.c hyperentropy.c
 
 # autogenerated into the correct namespace
 RUMPOBJ_NORENAME= rump_syscalls.*o
@@ -98,6 +100,7 @@ SRCS+=	init_sysctl_base.c	\
 	subr_devsw.c		\
 	subr_callback.c		\
 	subr_copy.c		\
+	subr_cprng.c		\
 	subr_device.c		\
 	subr_evcnt.c		\
 	subr_extent.c		\
@@ -140,6 +143,14 @@ SRCS+=	vnode_if.c
 # sys/dev
 SRCS+=	clock_subr.c
 
+# sys/dev/crypto
+# Note: these are here only for cprng.  More crypto algos for drivers
+# are available from the rumpkern_crypto component
+SRCS+=	nist_ctr_drbg.c
+SRCS+=	rijndael-alg-fst.c
+SRCS+=	rijndael-api-fst.c
+SRCS+=	rijndael.c	
+
 # compat
 SRCS+=	kern_select_50.c
 

Index: src/sys/rump/librump/rumpkern/emul.c
diff -u src/sys/rump/librump/rumpkern/emul.c:1.160 src/sys/rump/librump/rumpkern/emul.c:1.161
--- src/sys/rump/librump/rumpkern/emul.c:1.160	Mon Dec 16 15:36:29 2013
+++ src/sys/rump/librump/rumpkern/emul.c	Fri Jan 17 01:32:53 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: emul.c,v 1.160 2013/12/16 15:36:29 pooka Exp $	*/
+/*	$NetBSD: emul.c,v 1.161 2014/01/17 01:32:53 pooka Exp $	*/
 
 /*
  * Copyright (c) 2007-2011 Antti Kantee.  All Rights Reserved.
@@ -26,7 +26,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: emul.c,v 1.160 2013/12/16 15:36:29 pooka Exp $);
+__KERNEL_RCSID(0, $NetBSD: emul.c,v 1.161 2014/01/17 01:32:53 pooka Exp $);
 
 #include sys/param.h
 #include sys/null.h
@@ -52,6 +52,7 @@ __KERNEL_RCSID(0, $NetBSD: emul.c,v 1.1
 #include sys/syscallvar.h
 #include sys/xcall.h
 #include sys/sleepq.h
+#include sys/cprng.h
 
 #include dev/cons.h
 
@@ -140,6 +141,8 @@ struct emul emul_netbsd = {
 
 u_int nprocs = 1;
 
+cprng_strong_t *kern_cprng;
+
 int
 kpause(const char *wmesg, bool intr, int timeo, kmutex_t *mtx)
 {

Index: src/sys/rump/librump/rumpkern/rump.c
diff -u src/sys/rump/librump/rumpkern/rump.c:1.281 src/sys/rump/librump/rumpkern/rump.c:1.282
--- src/sys/rump/librump/rumpkern/rump.c:1.281	Mon Dec 16 15:36:30 2013
+++ src/sys/rump/librump/rumpkern/rump.c	Fri Jan 17 

CVS commit: src/lib/libc/net

2014-01-16 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Jan 17 02:03:44 UTC 2014

Modified Files:
src/lib/libc/net: gethnamaddr.c

Log Message:
Move more code into the macro, and fix the bug where realloc would cause
a dangling pointer and memory corruption.


To generate a diff of this commit:
cvs rdiff -u -r1.86 -r1.87 src/lib/libc/net/gethnamaddr.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/net/gethnamaddr.c
diff -u src/lib/libc/net/gethnamaddr.c:1.86 src/lib/libc/net/gethnamaddr.c:1.87
--- src/lib/libc/net/gethnamaddr.c:1.86	Thu Jan 16 15:59:21 2014
+++ src/lib/libc/net/gethnamaddr.c	Thu Jan 16 21:03:44 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: gethnamaddr.c,v 1.86 2014/01/16 20:59:21 christos Exp $	*/
+/*	$NetBSD: gethnamaddr.c,v 1.87 2014/01/17 02:03:44 christos Exp $	*/
 
 /*
  * ++Copyright++ 1985, 1988, 1993
@@ -57,7 +57,7 @@
 static char sccsid[] = @(#)gethostnamadr.c	8.1 (Berkeley) 6/4/93;
 static char rcsid[] = Id: gethnamaddr.c,v 8.21 1997/06/01 20:34:37 vixie Exp ;
 #else
-__RCSID($NetBSD: gethnamaddr.c,v 1.86 2014/01/16 20:59:21 christos Exp $);
+__RCSID($NetBSD: gethnamaddr.c,v 1.87 2014/01/17 02:03:44 christos Exp $);
 #endif
 #endif /* LIBC_SCCS and not lint */
 
@@ -108,18 +108,22 @@ __weak_alias(gethostent,_gethostent)
 #define maybe_hnok(res, hn) maybe_ok((res), (hn), res_hnok)
 #define maybe_dnok(res, dn) maybe_ok((res), (dn), res_dnok)
 
-#define grow(arr, siz) do {			\
-	void *xptr = realloc(arr, siz + 10); 	\
-	if (xptr == NULL)			\
-		goto nospc;			\
-	arr = xptr;\
-	siz += 10;\
+#define addalias(d, s, arr, siz) do {			\
+	if (d = arr[siz - 1]) {			\
+		char **xptr = realloc(arr, siz + 10); 	\
+		if (xptr == NULL)			\
+			goto nospc;			\
+		d = xptr + (d - arr);			\
+		arr = xptr;\
+		siz += 10;\
+	}		\
+	*d++ = s;	\
 } while (/*CONSTCOND*/0)
 
-#define setup(arr, siz) do {			\
-	arr = malloc(siz = 10); 		\
-	if (arr == NULL)			\
-		goto nospc;			\
+#define setup(arr, siz) do {\
+	arr = malloc(siz = 10); 			\
+	if (arr == NULL)\
+		goto nospc;\
 } while (/*CONSTCOND*/0)
 
 
@@ -307,8 +311,6 @@ getanswer(const querybuf *answer, int an
 			continue;		/* XXX - had_error++ ? */
 		}
 		if ((qtype == T_A || qtype == T_)  type == T_CNAME) {
-			if (ap = aliases[maxaliases - 1])
-grow(aliases, maxaliases);
 			n = dn_expand(answer-buf, eom, cp, tbuf,
 			(int)sizeof tbuf);
 			if ((n  0) || !maybe_ok(res, tbuf, name_ok)) {
@@ -319,7 +321,7 @@ getanswer(const querybuf *answer, int an
 			if (cp != erdata)
 goto no_recovery;
 			/* Store alias. */
-			*ap++ = bp;
+			addalias(ap, bp, aliases, maxaliases);
 			n = (int)strlen(bp) + 1;	/* for the \0 */
 			if (n = MAXHOSTNAMELEN) {
 had_error++;
@@ -386,11 +388,8 @@ getanswer(const querybuf *answer, int an
 goto no_recovery;
 			if (!haveanswer)
 hent-h_name = bp;
-			else {
-if (ap = aliases[maxaliases - 1])
-	grow(aliases, maxaliases);
-*ap++ = bp;
-			}
+			else
+addalias(ap, bp, aliases, maxaliases);
 			if (n != -1) {
 n = (int)strlen(bp) + 1;	/* for the \0 */
 if (n = MAXHOSTNAMELEN) {
@@ -808,8 +807,7 @@ gethostent_r(FILE *hf, struct hostent *h
 			cp++;
 			continue;
 		}
-		if (q = aliases[maxaliases - 1])
-			grow(aliases, maxaliases);
+		addalias(q, cp, aliases, maxaliases);
 		*q++ = cp;
 		if ((cp = strpbrk(cp,  \t)) != NULL)
 			*cp++ = '\0';
@@ -1173,11 +1171,8 @@ nextline:
 		hp-h_name = p;
 	else if (strcmp(hp-h_name, p) == 0)
 		;
-	else {
-		if (q = aliases[maxaliases - 1])
-			grow(aliases, maxaliases);
-		*q++ = p;
-	}
+	else
+		addalias(q, p, aliases, maxaliases);
 	p = cp;
 	if (more)
 		goto nextline;
@@ -1191,8 +1186,7 @@ nextline:
 			cp++;
 			goto nextline;
 		}
-		if (q = aliases[maxaliases - 1])
-			grow(aliases, maxaliases);
+		addalias(q, cp, aliases, maxaliases);
 		*q++ = cp;
 		cp = strpbrk(cp,  \t);
 		if (cp != NULL)



CVS commit: src/sys/rump/librump/rumpkern

2014-01-16 Thread Antti Kantee
Module Name:src
Committed By:   pooka
Date:   Fri Jan 17 02:05:54 UTC 2014

Modified Files:
src/sys/rump/librump/rumpkern: rump.c

Log Message:
sysctl_init needs to be pretty much at the top of main()


To generate a diff of this commit:
cvs rdiff -u -r1.282 -r1.283 src/sys/rump/librump/rumpkern/rump.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/rump/librump/rumpkern/rump.c
diff -u src/sys/rump/librump/rumpkern/rump.c:1.282 src/sys/rump/librump/rumpkern/rump.c:1.283
--- src/sys/rump/librump/rumpkern/rump.c:1.282	Fri Jan 17 01:32:53 2014
+++ src/sys/rump/librump/rumpkern/rump.c	Fri Jan 17 02:05:54 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: rump.c,v 1.282 2014/01/17 01:32:53 pooka Exp $	*/
+/*	$NetBSD: rump.c,v 1.283 2014/01/17 02:05:54 pooka Exp $	*/
 
 /*
  * Copyright (c) 2007-2011 Antti Kantee.  All Rights Reserved.
@@ -26,7 +26,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: rump.c,v 1.282 2014/01/17 01:32:53 pooka Exp $);
+__KERNEL_RCSID(0, $NetBSD: rump.c,v 1.283 2014/01/17 02:05:54 pooka Exp $);
 
 #include sys/systm.h
 #define ELFSIZE ARCH_ELFSIZE
@@ -336,6 +336,7 @@ rump_init(void)
 	kauth_init();
 
 	secmodel_init();
+	sysctl_init();
 
 	rnd_init();
 	cprng_init();
@@ -345,7 +346,6 @@ rump_init(void)
 
 	procinit();
 	proc0_init();
-	sysctl_init();
 	uid_init();
 	chgproccnt(0, 1);
 



CVS commit: src/sys/sys

2014-01-16 Thread Antti Kantee
Module Name:src
Committed By:   pooka
Date:   Fri Jan 17 02:08:56 UTC 2014

Modified Files:
src/sys/sys: cprng.h

Log Message:
forgot to commit this with rump kernelcprng change


To generate a diff of this commit:
cvs rdiff -u -r1.8 -r1.9 src/sys/sys/cprng.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/sys/cprng.h
diff -u src/sys/sys/cprng.h:1.8 src/sys/sys/cprng.h:1.9
--- src/sys/sys/cprng.h:1.8	Mon Jul  1 15:22:00 2013
+++ src/sys/sys/cprng.h	Fri Jan 17 02:08:56 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: cprng.h,v 1.8 2013/07/01 15:22:00 riastradh Exp $ */
+/*	$NetBSD: cprng.h,v 1.9 2014/01/17 02:08:56 pooka Exp $ */
 
 /*-
  * Copyright (c) 2011-2013 The NetBSD Foundation, Inc.
@@ -47,7 +47,6 @@
  */
 #define CPRNG_MAX_LEN	524288
 
-#if !defined(_RUMPKERNEL)  !defined(_RUMP_NATIVE_ABI)
 /*
  * We do not want an arc4random() prototype available to anyone.
  */
@@ -74,11 +73,6 @@ cprng_fast64(void)
 	_arc4randbytes(r, sizeof(r));
 	return r;
 }
-#else
-size_t cprng_fast(void *, size_t);
-uint32_t cprng_fast32(void);
-uint64_t cprng_fast64(void);
-#endif
 
 typedef struct cprng_strong cprng_strong_t;
 



CVS commit: src/lib/libc/net

2014-01-16 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Jan 17 02:08:44 UTC 2014

Modified Files:
src/lib/libc/net: gethnamaddr.c

Log Message:
the addition is handled in the alias.


To generate a diff of this commit:
cvs rdiff -u -r1.87 -r1.88 src/lib/libc/net/gethnamaddr.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libc/net/gethnamaddr.c
diff -u src/lib/libc/net/gethnamaddr.c:1.87 src/lib/libc/net/gethnamaddr.c:1.88
--- src/lib/libc/net/gethnamaddr.c:1.87	Thu Jan 16 21:03:44 2014
+++ src/lib/libc/net/gethnamaddr.c	Thu Jan 16 21:08:44 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: gethnamaddr.c,v 1.87 2014/01/17 02:03:44 christos Exp $	*/
+/*	$NetBSD: gethnamaddr.c,v 1.88 2014/01/17 02:08:44 christos Exp $	*/
 
 /*
  * ++Copyright++ 1985, 1988, 1993
@@ -57,7 +57,7 @@
 static char sccsid[] = @(#)gethostnamadr.c	8.1 (Berkeley) 6/4/93;
 static char rcsid[] = Id: gethnamaddr.c,v 8.21 1997/06/01 20:34:37 vixie Exp ;
 #else
-__RCSID($NetBSD: gethnamaddr.c,v 1.87 2014/01/17 02:03:44 christos Exp $);
+__RCSID($NetBSD: gethnamaddr.c,v 1.88 2014/01/17 02:08:44 christos Exp $);
 #endif
 #endif /* LIBC_SCCS and not lint */
 
@@ -808,7 +808,6 @@ gethostent_r(FILE *hf, struct hostent *h
 			continue;
 		}
 		addalias(q, cp, aliases, maxaliases);
-		*q++ = cp;
 		if ((cp = strpbrk(cp,  \t)) != NULL)
 			*cp++ = '\0';
 	}
@@ -1187,7 +1186,6 @@ nextline:
 			goto nextline;
 		}
 		addalias(q, cp, aliases, maxaliases);
-		*q++ = cp;
 		cp = strpbrk(cp,  \t);
 		if (cp != NULL)
 			*cp++ = '\0';



CVS commit: src/sys

2014-01-16 Thread Antti Kantee
Module Name:src
Committed By:   pooka
Date:   Fri Jan 17 02:12:49 UTC 2014

Modified Files:
src/sys/kern: init_sysctl.c kern_sysctl.c subr_cprng.c
src/sys/sys: sysctl.h

Log Message:
Put cprng sysctls into subr_cprng.c.  Also, make sysctl_prng static
in subr_cprng and get rid of SYSCTL_PRIVATE namespace leak macro.

Fixes ping(8) when run against a standalone rump kernel due to appearance
of the kern.urandom sysctl node (in case someone was wondering ...)


To generate a diff of this commit:
cvs rdiff -u -r1.198 -r1.199 src/sys/kern/init_sysctl.c
cvs rdiff -u -r1.243 -r1.244 src/sys/kern/kern_sysctl.c
cvs rdiff -u -r1.22 -r1.23 src/sys/kern/subr_cprng.c
cvs rdiff -u -r1.209 -r1.210 src/sys/sys/sysctl.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/kern/init_sysctl.c
diff -u src/sys/kern/init_sysctl.c:1.198 src/sys/kern/init_sysctl.c:1.199
--- src/sys/kern/init_sysctl.c:1.198	Sat Sep 14 13:18:02 2013
+++ src/sys/kern/init_sysctl.c	Fri Jan 17 02:12:48 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: init_sysctl.c,v 1.198 2013/09/14 13:18:02 joerg Exp $ */
+/*	$NetBSD: init_sysctl.c,v 1.199 2014/01/17 02:12:48 pooka Exp $ */
 
 /*-
  * Copyright (c) 2003, 2007, 2008, 2009 The NetBSD Foundation, Inc.
@@ -30,15 +30,13 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: init_sysctl.c,v 1.198 2013/09/14 13:18:02 joerg Exp $);
+__KERNEL_RCSID(0, $NetBSD: init_sysctl.c,v 1.199 2014/01/17 02:12:48 pooka Exp $);
 
 #include opt_sysv.h
 #include opt_compat_netbsd.h
 #include opt_modular.h
 #include pty.h
 
-#define SYSCTL_PRIVATE
-
 #include sys/types.h
 #include sys/param.h
 #include sys/sysctl.h
@@ -115,8 +113,6 @@ static int sysctl_kern_cptime(SYSCTLFN_P
 #if NPTY  0
 static int sysctl_kern_maxptys(SYSCTLFN_PROTO);
 #endif /* NPTY  0 */
-static int sysctl_kern_urnd(SYSCTLFN_PROTO);
-static int sysctl_kern_arnd(SYSCTLFN_PROTO);
 static int sysctl_kern_lwp(SYSCTLFN_PROTO);
 static int sysctl_kern_forkfsleep(SYSCTLFN_PROTO);
 static int sysctl_kern_root_partition(SYSCTLFN_PROTO);
@@ -491,18 +487,6 @@ SYSCTL_SETUP(sysctl_kern_setup, sysctl 
 		   NULL, _POSIX_MONOTONIC_CLOCK, NULL, 0,
 		   CTL_KERN, KERN_MONOTONIC_CLOCK, CTL_EOL);
 	sysctl_createv(clog, 0, NULL, NULL,
-		   CTLFLAG_PERMANENT,
-		   CTLTYPE_INT, urandom,
-		   SYSCTL_DESCR(Random integer value),
-		   sysctl_kern_urnd, 0, NULL, 0,
-		   CTL_KERN, KERN_URND, CTL_EOL);
-	sysctl_createv(clog, 0, NULL, NULL,
-		   CTLFLAG_PERMANENT,
-		   CTLTYPE_INT, arandom,
-		   SYSCTL_DESCR(n bytes of random data),
-		   sysctl_kern_arnd, 0, NULL, 0,
-		   CTL_KERN, KERN_ARND, CTL_EOL);
-	sysctl_createv(clog, 0, NULL, NULL,
 		   CTLFLAG_PERMANENT|CTLFLAG_IMMEDIATE,
 		   CTLTYPE_INT, labelsector,
 		   SYSCTL_DESCR(Sector number containing the disklabel),
@@ -1298,64 +1282,6 @@ sysctl_kern_maxptys(SYSCTLFN_ARGS)
 #endif /* NPTY  0 */
 
 /*
- * sysctl helper routine for kern.urandom node. Picks a random number
- * for you.
- */
-static int
-sysctl_kern_urnd(SYSCTLFN_ARGS)
-{
-	int v, rv;
-
-	rv = cprng_strong(sysctl_prng, v, sizeof(v), 0);
-	if (rv == sizeof(v)) {
-		struct sysctlnode node = *rnode;
-		node.sysctl_data = v;
-		return (sysctl_lookup(SYSCTLFN_CALL(node)));
-	}
-	else
-		return (EIO);	/*XXX*/
-}
-
-/*
- * sysctl helper routine for kern.arandom node. Picks a random number
- * for you.
- */
-static int
-sysctl_kern_arnd(SYSCTLFN_ARGS)
-{
-	int error;
-	void *v;
-	struct sysctlnode node = *rnode;
-
-	if (*oldlenp == 0)
-		return 0;
-	/*
-	 * This code used to allow sucking 8192 bytes at a time out
-	 * of the kernel arc4random generator.  Evidently there is some
-	 * very old OpenBSD application code that may try to do this.
-	 *
-	 * Note that this node is documented as type INT -- 4 or 8
-	 * bytes, not 8192.
-	 *
-	 * We continue to support this abuse of the len pointer here
-	 * but only 256 bytes at a time, as, anecdotally, the actual
-	 * application use here was to generate RC4 keys in userspace.
-	 *
-	 * Support for such large requests will probably be removed
-	 * entirely in the future.
-	 */
-	if (*oldlenp  256)
-		return E2BIG;
-
-	v = kmem_alloc(*oldlenp, KM_SLEEP);
-	cprng_fast(v, *oldlenp);
-	node.sysctl_data = v;
-	node.sysctl_size = *oldlenp;
-	error = sysctl_lookup(SYSCTLFN_CALL(node));
-	kmem_free(v, *oldlenp);
-	return error;
-}
-/*
  * sysctl helper routine to do kern.lwp.* work.
  */
 static int

Index: src/sys/kern/kern_sysctl.c
diff -u src/sys/kern/kern_sysctl.c:1.243 src/sys/kern/kern_sysctl.c:1.244
--- src/sys/kern/kern_sysctl.c:1.243	Sat Apr 27 20:13:16 2013
+++ src/sys/kern/kern_sysctl.c	Fri Jan 17 02:12:48 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: kern_sysctl.c,v 1.243 2013/04/27 20:13:16 christos Exp $	*/
+/*	$NetBSD: kern_sysctl.c,v 1.244 2014/01/17 02:12:48 pooka Exp $	*/
 
 /*-
  * Copyright (c) 2003, 2007, 2008 The NetBSD Foundation, Inc.
@@ -68,13 

CVS commit: src/usr.bin/fstat

2014-01-16 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Jan 17 03:28:01 UTC 2014

Modified Files:
src/usr.bin/fstat: fstat.c

Log Message:
make fstat -f search for unix sockets.


To generate a diff of this commit:
cvs rdiff -u -r1.106 -r1.107 src/usr.bin/fstat/fstat.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.bin/fstat/fstat.c
diff -u src/usr.bin/fstat/fstat.c:1.106 src/usr.bin/fstat/fstat.c:1.107
--- src/usr.bin/fstat/fstat.c:1.106	Sun Dec 15 13:56:59 2013
+++ src/usr.bin/fstat/fstat.c	Thu Jan 16 22:28:01 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: fstat.c,v 1.106 2013/12/15 18:56:59 mlelstv Exp $	*/
+/*	$NetBSD: fstat.c,v 1.107 2014/01/17 03:28:01 christos Exp $	*/
 
 /*-
  * Copyright (c) 1988, 1993
@@ -39,7 +39,7 @@ __COPYRIGHT(@(#) Copyright (c) 1988, 19
 #if 0
 static char sccsid[] = @(#)fstat.c	8.3 (Berkeley) 5/2/95;
 #else
-__RCSID($NetBSD: fstat.c,v 1.106 2013/12/15 18:56:59 mlelstv Exp $);
+__RCSID($NetBSD: fstat.c,v 1.107 2014/01/17 03:28:01 christos Exp $);
 #endif
 #endif /* not lint */
 
@@ -510,8 +510,7 @@ ftrans(fdfile_t *fp, int i)
 		vtrans(file.f_data, i, file.f_flag, (long)fdfile.ff_file);
 		break;
 	case DTYPE_SOCKET:
-		if (checkfile == 0)
-			socktrans(file.f_data, i);
+		socktrans(file.f_data, i);
 		break;
 	case DTYPE_PIPE:
 		if (checkfile == 0)
@@ -598,37 +597,49 @@ vfilestat(struct vnode *vp, struct files
 	return badtype;
 }
 
-static void
-vtrans(struct vnode *vp, int i, int flag, long addr)
+static int
+checkfs(struct vnode *vp, struct vnode *vn, struct filestat *fst,
+const char **type, const char **fname)
 {
-	struct vnode vn;
-	struct filestat fst;
-	char mode[15], rw[3];
-	const char *badtype, *filename;
-
-	filename = NULL;
-	if (!KVM_READ(vp, vn, sizeof(struct vnode))) {
+	*fname = NULL;
+	if (!KVM_READ(vp, vn, sizeof(*vn))) {
 		dprintf(can't read vnode at %p for pid %d, vp, Pid);
-		return;
+		return 0;
 	}
-	badtype = vfilestat(vn, fst);
+	*type = vfilestat(vn, fst);
 	if (checkfile) {
 		int fsmatch = 0;
 		DEVS *d;
-
-		if (badtype  badtype != dead)
-			return;
-		for (d = devs; d != NULL; d = d-next)
-			if (d-fsid == fst.fsid) {
+#if 0
+		if (*type  *type != dead)
+			return 0;
+#endif
+		for (d = devs; d != NULL; d = d-next) {
+			if (d-fsid == fst-fsid) {
 fsmatch = 1;
-if (d-ino == fst.fileid) {
-	filename = d-name;
+if (d-ino == fst-fileid) {
+	*fname = d-name;
 	break;
 }
 			}
-		if (fsmatch == 0 || (filename == NULL  fsflg == 0))
-			return;
+		}
+		if (fsmatch == 0 || (*fname == NULL  fsflg == 0))
+			return 0;
 	}
+	return 1;
+}
+
+static void
+vtrans(struct vnode *vp, int i, int flag, long addr)
+{
+	struct vnode vn;
+	char mode[15], rw[3];
+	const char *badtype, *filename;
+	struct filestat fst;
+
+	if (!checkfs(vp, vn, fst, badtype, filename))
+		return;
+
 	if (Aflg)
 		(void)printf(%*lx , 2*(int)(sizeof(void*)), addr);
 	PREFIX(i);
@@ -999,7 +1010,6 @@ socktrans(struct socket *sock, int i)
 	int len;
 	char dname[32];
 	char lbuf[512], fbuf[512];
-	PREFIX(i);
 
 	/* fill in socket */
 	if (!KVM_READ(sock, so, sizeof(struct socket))) {
@@ -1019,6 +1029,9 @@ socktrans(struct socket *sock, int i)
 		goto bad;
 	}
 
+	if (checkfile  dom.dom_family != AF_LOCAL)
+		return;
+
 	if ((len = kvm_read(kd, (u_long)dom.dom_name, dname,
 	sizeof(dname) - 1)) != sizeof(dname) -1) {
 		dprintf(can't read domain name at %p, dom.dom_name);
@@ -1027,11 +1040,6 @@ socktrans(struct socket *sock, int i)
 	else
 		dname[len] = '\0';
 
-	if ((u_short)so.so_type  STYPEMAX)
-		(void)printf(* %s ?%d, dname, so.so_type);
-	else
-		(void)printf(* %s %s, dname, stypename[so.so_type]);
-
 	/* 
 	 * protocol specific formatting
 	 *
@@ -1112,6 +1120,16 @@ again:
 dprintf(can't read unpcb at %p, so.so_pcb);
 goto bad;
 			}
+			if (checkfile) {
+struct vnode vn;
+struct filestat fst;
+const char *badtype, *filename;
+if (unpcb.unp_vnode == NULL)
+	return;
+if (!checkfs(unpcb.unp_vnode, vn, fst,
+badtype, filename))
+	return;
+			}
 
 			if (unpcb.unp_addr) {
 struct sockaddr_un *sun = 
@@ -1162,6 +1180,12 @@ again:
 		(uintmax_t)(uintptr_t)sock);
 		break;
 	}
+	PREFIX(i);
+	if ((u_short)so.so_type  STYPEMAX)
+		(void)printf(* %s ?%d, dname, so.so_type);
+	else
+		(void)printf(* %s %s, dname, stypename[so.so_type]);
+
 	if (fbuf[0] || lbuf[0])
 		printf( %s%s%s, fbuf, (fbuf[0]  lbuf[0]) ?  -  : ,
 		lbuf);



CVS commit: src/sys/arch/hp700/dev

2014-01-16 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Fri Jan 17 07:44:16 UTC 2014

Modified Files:
src/sys/arch/hp700/dev: lasi.c

Log Message:
Fix lasi at mainbus attachment, e.g. on a HP715/100.


To generate a diff of this commit:
cvs rdiff -u -r1.24 -r1.25 src/sys/arch/hp700/dev/lasi.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/hp700/dev/lasi.c
diff -u src/sys/arch/hp700/dev/lasi.c:1.24 src/sys/arch/hp700/dev/lasi.c:1.25
--- src/sys/arch/hp700/dev/lasi.c:1.24	Sat Oct 19 13:49:11 2013
+++ src/sys/arch/hp700/dev/lasi.c	Fri Jan 17 07:44:16 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: lasi.c,v 1.24 2013/10/19 13:49:11 skrll Exp $	*/
+/*	$NetBSD: lasi.c,v 1.25 2014/01/17 07:44:16 skrll Exp $	*/
 
 /*	$OpenBSD: lasi.c,v 1.4 2001/06/09 03:57:19 mickey Exp $	*/
 
@@ -29,7 +29,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: lasi.c,v 1.24 2013/10/19 13:49:11 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: lasi.c,v 1.25 2014/01/17 07:44:16 skrll Exp $);
 
 #undef LASIDEBUG
 
@@ -200,6 +200,15 @@ lasiattach(device_t parent, device_t sel
 
 	/* Attach the GSC bus. */
 	ga.ga_ca = *ca;	/* clone from us */
+	if (strcmp(device_xname(parent), mainbus0) == 0) {
+		ga.ga_dp.dp_bc[0] = ga.ga_dp.dp_bc[1];
+		ga.ga_dp.dp_bc[1] = ga.ga_dp.dp_bc[2];
+		ga.ga_dp.dp_bc[2] = ga.ga_dp.dp_bc[3];
+		ga.ga_dp.dp_bc[3] = ga.ga_dp.dp_bc[4];
+		ga.ga_dp.dp_bc[4] = ga.ga_dp.dp_bc[5];
+		ga.ga_dp.dp_bc[5] = ga.ga_dp.dp_mod;
+		ga.ga_dp.dp_mod = 0;
+	}
 
 	ga.ga_name = gsc;
 	ga.ga_ir = sc-sc_ir;
Index: src/lib/libc/gen/Makefile.inc
diff -u src/lib/libc/gen/Makefile.inc:1.186 src/lib/libc/gen/Makefile.inc:1.187
--- 

CVS commit: src/sys/dev/usb

2014-01-16 Thread David Laight
Module Name:src
Committed By:   dsl
Date:   Thu Jan 16 20:55:56 UTC 2014

Modified Files:
src/sys/dev/usb: xhci.c

Log Message:
Add another XXX comment, I'm not in a postition to fix the code.
The 'cycle' bit of a LINK trb must not be changed until the cycle bit
of the following trb has been set.


To generate a diff of this commit:
cvs rdiff -u -r1.12 -r1.13 src/sys/dev/usb/xhci.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/xhci.c
diff -u src/sys/dev/usb/xhci.c:1.12 src/sys/dev/usb/xhci.c:1.13
--- src/sys/dev/usb/xhci.c:1.12	Sat Dec 14 16:03:04 2013
+++ src/sys/dev/usb/xhci.c	Thu Jan 16 20:55:56 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: xhci.c,v 1.12 2013/12/14 16:03:04 jakllsch Exp $	*/
+/*	$NetBSD: xhci.c,v 1.13 2014/01/16 20:55:56 dsl Exp $	*/
 
 /*
  * Copyright (c) 2013 Jonathan A. Kollasch
@@ -27,7 +27,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: xhci.c,v 1.12 2013/12/14 16:03:04 jakllsch Exp $);
+__KERNEL_RCSID(0, $NetBSD: xhci.c,v 1.13 2014/01/16 20:55:56 dsl Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -1629,6 +1629,11 @@ xhci_ring_put(struct xhci_softc * const 
 	 * Arbitrary aligned LINK trb definitely fail on Ivy bridge.
 	 * The simple solution is not to allow a LINK trb in the middle
 	 * of anything - as here.
+	 * XXX: (dsl) There are xhci controllers out there (eg some made by
+	 * ASMedia) that seem to lock up if they process a LINK trb but
+	 * cannot process the linked-to trb yet.
+	 * The code should write the 'cycle' bit on the link trb AFTER
+	 * adding the other trb.
 	 */
 	if (ri + ntrbs = (xr-xr_ntrb - 1)) {
 		parameter = xhci_ring_trbp(xr, 0);
@@ -2671,7 +2676,7 @@ xhci_device_bulk_start(usbd_xfer_handle 
 
 	parameter = DMAADDR(dma, 0);
 	/*
 	 * XXX: The physical buffer must not cross a 64k boundary.
 	 * If the user supplied buffer crosses such a boundary then 2
 	 * (or more) TRB should be used.
 	 * If multiple TRB are used the td_size field must be set correctly.
@@ -2671,7 +2676,7 @@ xhci_device_bulk_start(usbd_xfer_handle 
 	parameter = DMAADDR(dma, 0);
 	/*
-	 * XXX: The physical buffer must not cross a 64k boundary.
+	 * XXX: (dsl) The physical buffer must not cross a 64k boundary.
 	 * If the user supplied buffer crosses such a boundary then 2
 	 * (or more) TRB should be used.



CVS commit: src/lib/libc/net

2014-01-16 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Jan 16 20:59:21 UTC 2014

Modified Files:
src/lib/libc/net: gethnamaddr.c

Log Message:
Remove MAXALIASES limit


To generate a diff of this commit:
cvs rdiff -u -r1.85 -r1.86 src/lib/libc/net/gethnamaddr.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:
